

daycast_response = {
    "response": {
        "version": "0.1",
        "termsofService": "http://www.wunderground.com/weather/api/d/terms.html",
        "features": {
            "forecast": 1
        }
    },
    "forecast": {
        "txt_forecast": {
            "date": "2:00 PM PDT",
            "forecastday": [{
                "period": 0,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Tuesday",
                "fcttext": "Partly cloudy in the morning, then clear. High of 68F. Breezy. Winds from the West at 10 to 25 mph.",
                "fcttext_metric": "Partly cloudy in the morning, then clear. High of 20C. Windy. Winds from the West at 20 to 35 km/h.",
                "pop": "0"
            }, {
                "period": 1,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Tuesday Night",
                "fcttext": "Mostly cloudy. Fog overnight. Low of 50F. Winds from the WSW at 5 to 15 mph.",
                "fcttext_metric": "Mostly cloudy. Fog overnight. Low of 10C. Breezy. Winds from the WSW at 10 to 20 km/h.",
                "pop": "0"
            }, {
                "period": 2,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Wednesday",
                "fcttext": "Mostly cloudy. Fog early. High of 72F. Winds from the WSW at 10 to 15 mph.",
                "fcttext_metric": "Mostly cloudy. Fog early. High of 22C. Breezy. Winds from the WSW at 15 to 20 km/h.",
                "pop": "0"
            }, {
                "period": 3,
                "icon": "mostlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/mostlycloudy.gif",
                "title": "Wednesday Night",
                "fcttext": "Overcast. Fog overnight. Low of 54F. Winds from the WSW at 5 to 15 mph.",
                "fcttext_metric": "Overcast. Fog overnight. Low of 12C. Breezy. Winds from the WSW at 10 to 20 km/h.",
                "pop": "0"
            }, {
                "period": 4,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Thursday",
                "fcttext": "Overcast in the morning, then partly cloudy. Fog early. High of 72F. Winds from the WSW at 10 to 15 mph.",
                "fcttext_metric": "Overcast in the morning, then partly cloudy. Fog early. High of 22C. Breezy. Winds from the WSW at 15 to 25 km/h.",
                "pop": "0"
            }, {
                "period": 5,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Thursday Night",
                "fcttext": "Partly cloudy in the evening, then overcast. Fog overnight. Low of 54F. Winds from the WNW at 5 to 15 mph.",
                "fcttext_metric": "Partly cloudy in the evening, then overcast. Fog overnight. Low of 12C. Breezy. Winds from the WNW at 10 to 20 km/h.",
                "pop": "0"
            }, {
                "period": 6,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Friday",
                "fcttext": "Overcast in the morning, then partly cloudy. Fog early. High of 68F. Winds from the West at 5 to 15 mph.",
                "fcttext_metric": "Overcast in the morning, then partly cloudy. Fog early. High of 20C. Breezy. Winds from the West at 10 to 20 km/h.",
                "pop": "0"
            }, {
                "period": 7,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Friday Night",
                "fcttext": "Mostly cloudy. Fog overnight. Low of 52F. Winds from the West at 5 to 10 mph.",
                "fcttext_metric": "Mostly cloudy. Fog overnight. Low of 11C. Winds from the West at 10 to 15 km/h.",
                "pop": "0"
            }]
        },
        "simpleforecast": {
            "forecastday": [{
                "date": {
                    "epoch": "1340776800",
                    "pretty": "11:00 PM PDT on June 26, 2012",
                    "day": 26,
                    "month": 6,
                    "year": 2012,
                    "yday": 177,
                    "hour": 23,
                    "min": "00",
                    "sec": 0,
                    "isdst": "1",
                    "monthname": "June",
                    "weekday_short": "Tue",
                    "weekday": "Tuesday",
                    "ampm": "PM",
                    "tz_short": "PDT",
                    "tz_long": "America/Los_Angeles"
                },
                "period": 1,
                "high": {
                    "fahrenheit": "68",
                    "celsius": "20"
                },
                "low": {
                    "fahrenheit": "50",
                    "celsius": "10"
                },
                "conditions": "Partly Cloudy",
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "skyicon": "mostlysunny",
                "pop": 0,
                "qpf_allday": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_day": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_night": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "snow_allday": {
                    "in": 0,
                    "cm": 0
                },
                "snow_day": {
                    "in": 0,
                    "cm": 0
                },
                "snow_night": {
                    "in": 0,
                    "cm": 0
                },
                "maxwind": {
                    "mph": 21,
                    "kph": 34,
                    "dir": "West",
                    "degrees": 272
                },
                "avewind": {
                    "mph": 17,
                    "kph": 27,
                    "dir": "West",
                    "degrees": 272
                },
                "avehumidity": 72,
                "maxhumidity": 94,
                "minhumidity": 58
            }, {
                "date": {
                    "epoch": "1340863200",
                    "pretty": "11:00 PM PDT on June 27, 2012",
                    "day": 27,
                    "month": 6,
                    "year": 2012,
                    "yday": 178,
                    "hour": 23,
                    "min": "00",
                    "sec": 0,
                    "isdst": "1",
                    "monthname": "June",
                    "weekday_short": "Wed",
                    "weekday": "Wednesday",
                    "ampm": "PM",
                    "tz_short": "PDT",
                    "tz_long": "America/Los_Angeles"
                },
                "period": 2,
                "high": {
                    "fahrenheit": "72",
                    "celsius": "22"
                },
                "low": {
                    "fahrenheit": "54",
                    "celsius": "12"
                },
                "conditions": "Partly Cloudy",
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "skyicon": "mostlysunny",
                "pop": 0,
                "qpf_allday": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_day": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_night": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "snow_allday": {
                    "in": 0,
                    "cm": 0
                },
                "snow_day": {
                    "in": 0,
                    "cm": 0
                },
                "snow_night": {
                    "in": 0,
                    "cm": 0
                },
                "maxwind": {
                    "mph": 11,
                    "kph": 18,
                    "dir": "WSW",
                    "degrees": 255
                },
                "avewind": {
                    "mph": 9,
                    "kph": 14,
                    "dir": "WSW",
                    "degrees": 252
                },
                "avehumidity": 70,
                "maxhumidity": 84,
                "minhumidity": 54
            }, {
                "date": {
                    "epoch": "1340949600",
                    "pretty": "11:00 PM PDT on June 28, 2012",
                    "day": 28,
                    "month": 6,
                    "year": 2012,
                    "yday": 179,
                    "hour": 23,
                    "min": "00",
                    "sec": 0,
                    "isdst": "1",
                    "monthname": "June",
                    "weekday_short": "Thu",
                    "weekday": "Thursday",
                    "ampm": "PM",
                    "tz_short": "PDT",
                    "tz_long": "America/Los_Angeles"
                },
                "period": 3,
                "high": {
                    "fahrenheit": "72",
                    "celsius": "22"
                },
                "low": {
                    "fahrenheit": "54",
                    "celsius": "12"
                },
                "conditions": "Partly Cloudy",
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "skyicon": "partlycloudy",
                "pop": 0,
                "qpf_allday": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_day": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_night": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "snow_allday": {
                    "in": 0,
                    "cm": 0
                },
                "snow_day": {
                    "in": 0,
                    "cm": 0
                },
                "snow_night": {
                    "in": 0,
                    "cm": 0
                },
                "maxwind": {
                    "mph": 14,
                    "kph": 22,
                    "dir": "West",
                    "degrees": 265
                },
                "avewind": {
                    "mph": 12,
                    "kph": 19,
                    "dir": "WSW",
                    "degrees": 256
                },
                "avehumidity": 80,
                "maxhumidity": 91,
                "minhumidity": 56
            }, {
                "date": {
                    "epoch": "1341036000",
                    "pretty": "11:00 PM PDT on June 29, 2012",
                    "day": 29,
                    "month": 6,
                    "year": 2012,
                    "yday": 180,
                    "hour": 23,
                    "min": "00",
                    "sec": 0,
                    "isdst": "1",
                    "monthname": "June",
                    "weekday_short": "Fri",
                    "weekday": "Friday",
                    "ampm": "PM",
                    "tz_short": "PDT",
                    "tz_long": "America/Los_Angeles"
                },
                "period": 4,
                "high": {
                    "fahrenheit": "68",
                    "celsius": "20"
                },
                "low": {
                    "fahrenheit": "52",
                    "celsius": "11"
                },
                "conditions": "Fog",
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "skyicon": "mostlysunny",
                "pop": 0,
                "qpf_allday": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_day": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_night": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "snow_allday": {
                    "in": 0,
                    "cm": 0
                },
                "snow_day": {
                    "in": 0,
                    "cm": 0
                },
                "snow_night": {
                    "in": 0,
                    "cm": 0
                },
                "maxwind": {
                    "mph": 11,
                    "kph": 18,
                    "dir": "West",
                    "degrees": 267
                },
                "avewind": {
                    "mph": 10,
                    "kph": 16,
                    "dir": "West",
                    "degrees": 272
                },
                "avehumidity": 79,
                "maxhumidity": 93,
                "minhumidity": 63
            }]
        }
    }
}

weekcast_response = {
    "response": {
        "version": "0.1",
        "termsofService": "http://www.wunderground.com/weather/api/d/terms.html",
        "features": {
            "forecast10day": 1
        }
    },
    "forecast": {
        "txt_forecast": {
            "date": "8:00 AM PDT",
            "forecastday": [{
                "period": 0,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Tuesday",
                "fcttext": "Overcast in the morning, then clear. High of 75F. Winds from the SSW at 5 to 20 mph.",
                "fcttext_metric": "Overcast in the morning, then clear. High of 24C. Windy. Winds from the SSW at 5 to 30 km/h.",
                "pop": "0"
            }, {
                "period": 1,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Tuesday Night",
                "fcttext": "Mostly cloudy. Low of 55F. Winds from the SW at 5 to 15 mph.",
                "fcttext_metric": "Mostly cloudy. Low of 13C. Breezy. Winds from the SW at 10 to 20 km/h.",
                "pop": "0"
            }, {
                "period": 2,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Wednesday",
                "fcttext": "Mostly cloudy in the morning, then clear. High of 72F. Winds from the SW at 10 to 15 mph.",
                "fcttext_metric": "Mostly cloudy in the morning, then clear. High of 22C. Breezy. Winds from the SW at 15 to 25 km/h.",
                "pop": "0"
            }, {
                "period": 3,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Wednesday Night",
                "fcttext": "Mostly cloudy. Fog overnight. Low of 55F. Winds from the SW at 10 to 15 mph.",
                "fcttext_metric": "Mostly cloudy. Fog overnight. Low of 13C. Breezy. Winds from the SW at 15 to 20 km/h.",
                "pop": "0"
            }, {
                "period": 4,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Thursday",
                "fcttext": "Mostly cloudy. Fog early. High of 70F. Winds from the WSW at 10 to 15 mph.",
                "fcttext_metric": "Mostly cloudy. Fog early. High of 21C. Windy. Winds from the WSW at 15 to 25 km/h.",
                "pop": "0"
            }, {
                "period": 5,
                "icon": "clear",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
                "title": "Thursday Night",
                "fcttext": "Partly cloudy. Fog overnight. Low of 55F. Winds from the WNW at 5 to 10 mph.",
                "fcttext_metric": "Partly cloudy. Fog overnight. Low of 13C. Winds from the WNW at 10 to 15 km/h.",
                "pop": "0"
            }, {
                "period": 6,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Friday",
                "fcttext": "Partly cloudy in the morning, then clear. High of 72F. Winds from the West at 5 to 15 mph.",
                "fcttext_metric": "Partly cloudy in the morning, then clear. High of 22C. Breezy. Winds from the West at 10 to 20 km/h.",
                "pop": "0"
            }, {
                "period": 7,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Friday Night",
                "fcttext": "Partly cloudy. Fog overnight. Low of 55F. Winds from the WNW at 5 to 10 mph.",
                "fcttext_metric": "Partly cloudy. Fog overnight. Low of 13C. Winds from the WNW at 10 to 15 km/h.",
                "pop": "0"
            }, {
                "period": 8,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Saturday",
                "fcttext": "Partly cloudy. Fog early. High of 73F. Winds from the West at 5 to 15 mph.",
                "fcttext_metric": "Partly cloudy. Fog early. High of 23C. Breezy. Winds from the West at 10 to 20 km/h.",
                "pop": "0"
            }, {
                "period": 9,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Saturday Night",
                "fcttext": "Clear. Fog overnight. Low of 55F. Winds from the West at 5 to 10 mph.",
                "fcttext_metric": "Clear. Fog overnight. Low of 13C. Winds from the West at 10 to 15 km/h.",
                "pop": "0"
            }, {
                "period": 10,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Sunday",
                "fcttext": "Partly cloudy. High of 72F. Winds from the West at 5 to 15 mph.",
                "fcttext_metric": "Partly cloudy. High of 22C. Breezy. Winds from the West at 10 to 20 km/h.",
                "pop": "0"
            }, {
                "period": 11,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Sunday Night",
                "fcttext": "Partly cloudy. Fog overnight. Low of 55F. Winds from the West at 5 to 10 mph.",
                "fcttext_metric": "Partly cloudy. Fog overnight. Low of 13C. Winds from the West at 10 to 15 km/h.",
                "pop": "0"
            }, {
                "period": 12,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Monday",
                "fcttext": "Clear. High of 70F. Winds from the West at 5 to 10 mph.",
                "fcttext_metric": "Clear. High of 21C. Breezy. Winds from the West at 10 to 20 km/h.",
                "pop": "0"
            }, {
                "period": 13,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Monday Night",
                "fcttext": "Partly cloudy. Fog overnight. Low of 55F. Winds from the West at 5 to 10 mph.",
                "fcttext_metric": "Partly cloudy. Fog overnight. Low of 13C. Winds from the West at 5 to 15 km/h.",
                "pop": "0"
            }, {
                "period": 14,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Tuesday",
                "fcttext": "Clear. High of 75F. Winds from the West at 5 to 10 mph.",
                "fcttext_metric": "Clear. High of 24C. Breezy. Winds from the West at 10 to 20 km/h.",
                "pop": "0"
            }, {
                "period": 15,
                "icon": "clear",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
                "title": "Tuesday Night",
                "fcttext": "Clear. Low of 59F. Winds from the West at 5 to 15 mph.",
                "fcttext_metric": "Clear. Low of 15C. Breezy. Winds from the West at 10 to 20 km/h.",
                "pop": "0"
            }, {
                "period": 16,
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "title": "Wednesday",
                "fcttext": "Clear. High of 73F. Winds from the West at 5 to 15 mph.",
                "fcttext_metric": "Clear. High of 23C. Winds from the West at 5 to 20 km/h.",
                "pop": "0"
            }, {
                "period": 17,
                "icon": "clear",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
                "title": "Wednesday Night",
                "fcttext": "Clear. Low of 59F. Winds from the West at 5 to 15 mph.",
                "fcttext_metric": "Clear. Low of 15C. Breezy. Winds from the West at 10 to 20 km/h.",
                "pop": "0"
            }, {
                "period": 18,
                "icon": "clear",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
                "title": "Thursday",
                "fcttext": "Clear. High of 73F. Winds from the West at 5 to 15 mph.",
                "fcttext_metric": "Clear. High of 23C. Winds from the West at 5 to 20 km/h.",
                "pop": "0"
            }, {
                "period": 19,
                "icon": "clear",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
                "title": "Thursday Night",
                "fcttext": "Clear. Low of 57F. Winds from the WSW at 5 to 10 mph.",
                "fcttext_metric": "Clear. Low of 14C. Winds from the WSW at 10 to 15 km/h.",
                "pop": "0"
            }]
        },
        "simpleforecast": {
            "forecastday": [{
                "date": {
                    "epoch": "1341381600",
                    "pretty": "11:00 PM PDT on July 03, 2012",
                    "day": 3,
                    "month": 7,
                    "year": 2012,
                    "yday": 184,
                    "hour": 23,
                    "min": "00",
                    "sec": 0,
                    "isdst": "1",
                    "monthname": "July",
                    "weekday_short": "Tue",
                    "weekday": "Tuesday",
                    "ampm": "PM",
                    "tz_short": "PDT",
                    "tz_long": "America/Los_Angeles"
                },
                "period": 1,
                "high": {
                    "fahrenheit": "75",
                    "celsius": "24"
                },
                "low": {
                    "fahrenheit": "55",
                    "celsius": "13"
                },
                "conditions": "Partly Cloudy",
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "skyicon": "mostlysunny",
                "pop": 0,
                "qpf_allday": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_day": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_night": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "snow_allday": {
                    "in": 0,
                    "cm": 0
                },
                "snow_day": {
                    "in": 0,
                    "cm": 0
                },
                "snow_night": {
                    "in": 0,
                    "cm": 0
                },
                "maxwind": {
                    "mph": 17,
                    "kph": 27,
                    "dir": "WSW",
                    "degrees": 255
                },
                "avewind": {
                    "mph": 14,
                    "kph": 22,
                    "dir": "WSW",
                    "degrees": 241
                },
                "avehumidity": 72,
                "maxhumidity": 82,
                "minhumidity": 62
            }, {
                "date": {
                    "epoch": "1341468000",
                    "pretty": "11:00 PM PDT on July 04, 2012",
                    "day": 4,
                    "month": 7,
                    "year": 2012,
                    "yday": 185,
                    "hour": 23,
                    "min": "00",
                    "sec": 0,
                    "isdst": "1",
                    "monthname": "July",
                    "weekday_short": "Wed",
                    "weekday": "Wednesday",
                    "ampm": "PM",
                    "tz_short": "PDT",
                    "tz_long": "America/Los_Angeles"
                },
                "period": 2,
                "high": {
                    "fahrenheit": "72",
                    "celsius": "22"
                },
                "low": {
                    "fahrenheit": "55",
                    "celsius": "13"
                },
                "conditions": "Partly Cloudy",
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "skyicon": "partlycloudy",
                "pop": 0,
                "qpf_allday": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_day": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_night": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "snow_allday": {
                    "in": 0,
                    "cm": 0
                },
                "snow_day": {
                    "in": 0,
                    "cm": 0
                },
                "snow_night": {
                    "in": 0,
                    "cm": 0
                },
                "maxwind": {
                    "mph": 15,
                    "kph": 24,
                    "dir": "WSW",
                    "degrees": 237
                },
                "avewind": {
                    "mph": 12,
                    "kph": 19,
                    "dir": "SW",
                    "degrees": 231
                },
                "avehumidity": 79,
                "maxhumidity": 89,
                "minhumidity": 54
            }, {
                "date": {
                    "epoch": "1341554400",
                    "pretty": "11:00 PM PDT on July 05, 2012",
                    "day": 5,
                    "month": 7,
                    "year": 2012,
                    "yday": 186,
                    "hour": 23,
                    "min": "00",
                    "sec": 0,
                    "isdst": "1",
                    "monthname": "July",
                    "weekday_short": "Thu",
                    "weekday": "Thursday",
                    "ampm": "PM",
                    "tz_short": "PDT",
                    "tz_long": "America/Los_Angeles"
                },
                "period": 3,
                "high": {
                    "fahrenheit": "70",
                    "celsius": "21"
                },
                "low": {
                    "fahrenheit": "55",
                    "celsius": "13"
                },
                "conditions": "Partly Cloudy",
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "skyicon": "mostlysunny",
                "pop": 0,
                "qpf_allday": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_day": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_night": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "snow_allday": {
                    "in": 0,
                    "cm": 0
                },
                "snow_day": {
                    "in": 0,
                    "cm": 0
                },
                "snow_night": {
                    "in": 0,
                    "cm": 0
                },
                "maxwind": {
                    "mph": 15,
                    "kph": 24,
                    "dir": "West",
                    "degrees": 265
                },
                "avewind": {
                    "mph": 13,
                    "kph": 21,
                    "dir": "WSW",
                    "degrees": 250
                },
                "avehumidity": 77,
                "maxhumidity": 87,
                "minhumidity": 64
            }, {
                "date": {
                    "epoch": "1341640800",
                    "pretty": "11:00 PM PDT on July 06, 2012",
                    "day": 6,
                    "month": 7,
                    "year": 2012,
                    "yday": 187,
                    "hour": 23,
                    "min": "00",
                    "sec": 0,
                    "isdst": "1",
                    "monthname": "July",
                    "weekday_short": "Fri",
                    "weekday": "Friday",
                    "ampm": "PM",
                    "tz_short": "PDT",
                    "tz_long": "America/Los_Angeles"
                },
                "period": 4,
                "high": {
                    "fahrenheit": "72",
                    "celsius": "22"
                },
                "low": {
                    "fahrenheit": "55",
                    "celsius": "13"
                },
                "conditions": "Partly Cloudy",
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "skyicon": "sunny",
                "pop": 0,
                "qpf_allday": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_day": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_night": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "snow_allday": {
                    "in": 0,
                    "cm": 0
                },
                "snow_day": {
                    "in": 0,
                    "cm": 0
                },
                "snow_night": {
                    "in": 0,
                    "cm": 0
                },
                "maxwind": {
                    "mph": 11,
                    "kph": 18,
                    "dir": "West",
                    "degrees": 272
                },
                "avewind": {
                    "mph": 9,
                    "kph": 14,
                    "dir": "West",
                    "degrees": 274
                },
                "avehumidity": 70,
                "maxhumidity": 84,
                "minhumidity": 58
            }, {
                "date": {
                    "epoch": "1341727200",
                    "pretty": "11:00 PM PDT on July 07, 2012",
                    "day": 7,
                    "month": 7,
                    "year": 2012,
                    "yday": 188,
                    "hour": 23,
                    "min": "00",
                    "sec": 0,
                    "isdst": "1",
                    "monthname": "July",
                    "weekday_short": "Sat",
                    "weekday": "Saturday",
                    "ampm": "PM",
                    "tz_short": "PDT",
                    "tz_long": "America/Los_Angeles"
                },
                "period": 5,
                "high": {
                    "fahrenheit": "73",
                    "celsius": "23"
                },
                "low": {
                    "fahrenheit": "55",
                    "celsius": "13"
                },
                "conditions": "Fog",
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "skyicon": "mostlysunny",
                "pop": 0,
                "qpf_allday": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_day": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_night": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "snow_allday": {
                    "in": 0,
                    "cm": 0
                },
                "snow_day": {
                    "in": 0,
                    "cm": 0
                },
                "snow_night": {
                    "in": 0,
                    "cm": 0
                },
                "maxwind": {
                    "mph": 11,
                    "kph": 18,
                    "dir": "West",
                    "degrees": 266
                },
                "avewind": {
                    "mph": 9,
                    "kph": 14,
                    "dir": "West",
                    "degrees": 270
                },
                "avehumidity": 75,
                "maxhumidity": 85,
                "minhumidity": 61
            }, {
                "date": {
                    "epoch": "1341813600",
                    "pretty": "11:00 PM PDT on July 08, 2012",
                    "day": 8,
                    "month": 7,
                    "year": 2012,
                    "yday": 189,
                    "hour": 23,
                    "min": "00",
                    "sec": 0,
                    "isdst": "1",
                    "monthname": "July",
                    "weekday_short": "Sun",
                    "weekday": "Sunday",
                    "ampm": "PM",
                    "tz_short": "PDT",
                    "tz_long": "America/Los_Angeles"
                },
                "period": 6,
                "high": {
                    "fahrenheit": "72",
                    "celsius": "22"
                },
                "low": {
                    "fahrenheit": "55",
                    "celsius": "13"
                },
                "conditions": "Fog",
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "skyicon": "partlycloudy",
                "pop": 0,
                "qpf_allday": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_day": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_night": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "snow_allday": {
                    "in": 0,
                    "cm": 0
                },
                "snow_day": {
                    "in": 0,
                    "cm": 0
                },
                "snow_night": {
                    "in": 0,
                    "cm": 0
                },
                "maxwind": {
                    "mph": 11,
                    "kph": 18,
                    "dir": "West",
                    "degrees": 265
                },
                "avewind": {
                    "mph": 9,
                    "kph": 14,
                    "dir": "West",
                    "degrees": 266
                },
                "avehumidity": 79,
                "maxhumidity": 88,
                "minhumidity": 66
            }, {
                "date": {
                    "epoch": "1341900000",
                    "pretty": "11:00 PM PDT on July 09, 2012",
                    "day": 9,
                    "month": 7,
                    "year": 2012,
                    "yday": 190,
                    "hour": 23,
                    "min": "00",
                    "sec": 0,
                    "isdst": "1",
                    "monthname": "July",
                    "weekday_short": "Mon",
                    "weekday": "Monday",
                    "ampm": "PM",
                    "tz_short": "PDT",
                    "tz_long": "America/Los_Angeles"
                },
                "period": 7,
                "high": {
                    "fahrenheit": "70",
                    "celsius": "21"
                },
                "low": {
                    "fahrenheit": "55",
                    "celsius": "13"
                },
                "conditions": "Partly Cloudy",
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "skyicon": "mostlysunny",
                "pop": 0,
                "qpf_allday": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_day": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_night": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "snow_allday": {
                    "in": 0,
                    "cm": 0
                },
                "snow_day": {
                    "in": 0,
                    "cm": 0
                },
                "snow_night": {
                    "in": 0,
                    "cm": 0
                },
                "maxwind": {
                    "mph": 10,
                    "kph": 16,
                    "dir": "West",
                    "degrees": 263
                },
                "avewind": {
                    "mph": 9,
                    "kph": 14,
                    "dir": "West",
                    "degrees": 269
                },
                "avehumidity": 85,
                "maxhumidity": 92,
                "minhumidity": 67
            }, {
                "date": {
                    "epoch": "1341986400",
                    "pretty": "11:00 PM PDT on July 10, 2012",
                    "day": 10,
                    "month": 7,
                    "year": 2012,
                    "yday": 191,
                    "hour": 23,
                    "min": "00",
                    "sec": 0,
                    "isdst": "1",
                    "monthname": "July",
                    "weekday_short": "Tue",
                    "weekday": "Tuesday",
                    "ampm": "PM",
                    "tz_short": "PDT",
                    "tz_long": "America/Los_Angeles"
                },
                "period": 8,
                "high": {
                    "fahrenheit": "75",
                    "celsius": "24"
                },
                "low": {
                    "fahrenheit": "59",
                    "celsius": "15"
                },
                "conditions": "Partly Cloudy",
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "skyicon": "sunny",
                "pop": 0,
                "qpf_allday": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_day": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_night": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "snow_allday": {
                    "in": 0,
                    "cm": 0
                },
                "snow_day": {
                    "in": 0,
                    "cm": 0
                },
                "snow_night": {
                    "in": 0,
                    "cm": 0
                },
                "maxwind": {
                    "mph": 10,
                    "kph": 16,
                    "dir": "West",
                    "degrees": 264
                },
                "avewind": {
                    "mph": 8,
                    "kph": 13,
                    "dir": "West",
                    "degrees": 263
                },
                "avehumidity": 78,
                "maxhumidity": 90,
                "minhumidity": 58
            }, {
                "date": {
                    "epoch": "1342072800",
                    "pretty": "11:00 PM PDT on July 11, 2012",
                    "day": 11,
                    "month": 7,
                    "year": 2012,
                    "yday": 192,
                    "hour": 23,
                    "min": "00",
                    "sec": 0,
                    "isdst": "1",
                    "monthname": "July",
                    "weekday_short": "Wed",
                    "weekday": "Wednesday",
                    "ampm": "PM",
                    "tz_short": "PDT",
                    "tz_long": "America/Los_Angeles"
                },
                "period": 9,
                "high": {
                    "fahrenheit": "73",
                    "celsius": "23"
                },
                "low": {
                    "fahrenheit": "59",
                    "celsius": "15"
                },
                "conditions": "Partly Cloudy",
                "icon": "partlycloudy",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/partlycloudy.gif",
                "skyicon": "mostlysunny",
                "pop": 0,
                "qpf_allday": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_day": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_night": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "snow_allday": {
                    "in": 0,
                    "cm": 0
                },
                "snow_day": {
                    "in": 0,
                    "cm": 0
                },
                "snow_night": {
                    "in": 0,
                    "cm": 0
                },
                "maxwind": {
                    "mph": 11,
                    "kph": 18,
                    "dir": "West",
                    "degrees": 273
                },
                "avewind": {
                    "mph": 8,
                    "kph": 13,
                    "dir": "West",
                    "degrees": 268
                },
                "avehumidity": 76,
                "maxhumidity": 93,
                "minhumidity": 58
            }, {
                "date": {
                    "epoch": "1342159200",
                    "pretty": "11:00 PM PDT on July 12, 2012",
                    "day": 12,
                    "month": 7,
                    "year": 2012,
                    "yday": 193,
                    "hour": 23,
                    "min": "00",
                    "sec": 0,
                    "isdst": "1",
                    "monthname": "July",
                    "weekday_short": "Thu",
                    "weekday": "Thursday",
                    "ampm": "PM",
                    "tz_short": "PDT",
                    "tz_long": "America/Los_Angeles"
                },
                "period": 10,
                "high": {
                    "fahrenheit": "73",
                    "celsius": "23"
                },
                "low": {
                    "fahrenheit": "57",
                    "celsius": "14"
                },
                "conditions": "Clear",
                "icon": "clear",
                "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
                "skyicon": "sunny",
                "pop": 0,
                "qpf_allday": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_day": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "qpf_night": {
                    "in": 0.00,
                    "mm": 0.0
                },
                "snow_allday": {
                    "in": 0,
                    "cm": 0
                },
                "snow_day": {
                    "in": 0,
                    "cm": 0
                },
                "snow_night": {
                    "in": 0,
                    "cm": 0
                },
                "maxwind": {
                    "mph": 11,
                    "kph": 18,
                    "dir": "West",
                    "degrees": 268
                },
                "avewind": {
                    "mph": 8,
                    "kph": 13,
                    "dir": "West",
                    "degrees": 263
                },
                "avehumidity": 71,
                "maxhumidity": 89,
                "minhumidity": 53
            }]
        }
    }
}

alerts_response = {
    "response": {
        "version": "0.1",
        "termsofService": "http://www.wunderground.com/weather/api/d/terms.html",
        "features": {
            "alerts": 1
        }
    },
    "alerts": [{
        "type": "HEA",
        "description": "Heat Advisory",
        "date": "11:14 am CDT on July 3, 2012",
        "date_epoch": "1341332040",
        "expires": "7:00 AM CDT on July 07, 2012",
        "expires_epoch": "1341662400",
        "message": "\u000A...Heat advisory remains in effect until 7 am CDT Saturday...\u000A\u000A* temperature...heat indices of 100 to 105 are expected each \u000A afternoon...as Max temperatures climb into the mid to upper \u000A 90s...combined with dewpoints in the mid 60s to around 70. \u000A Heat indices will remain in the 75 to 80 degree range at \u000A night. \u000A\u000A* Impacts...the hot and humid weather will lead to an increased \u000A risk of heat related stress and illnesses. \u000A\u000APrecautionary/preparedness actions...\u000A\u000AA heat advisory means that a period of hot temperatures is\u000Aexpected. The combination of hot temperatures and high humidity\u000Awill combine to create a situation in which heat illnesses are\u000Apossible. Drink plenty of fluids...stay in an air-conditioned\u000Aroom...stay out of the sun...and check up on relatives...pets...\u000Aneighbors...and livestock.\u000A\u000ATake extra precautions if you work or spend time outside. Know\u000Athe signs and symptoms of heat exhaustion and heat stroke. Anyone\u000Aovercome by heat should be moved to a cool and shaded location.\u000AHeat stroke is an emergency...call 9 1 1.\u000A\u000A\u000A\u000AMjb\u000A\u000A\u000A",
        "phenomena": "HT",
        "significance": "Y",
        "ZONES": [
            {
                "state": "UT",
                "ZONE": "001"
            }
        ],
        "StormBased": {
            "vertices": [
                {
                    "lat": "38.87",
                    "lon": "-87.13"
                },
                {
                    "lat": "38.89",
                    "lon": "-87.13"
                },
                {
                    "lat": "38.91",
                    "lon": "-87.11"
                },
                {
                    "lat": "38.98",
                    "lon": "-86.93"
                },
                {
                    "lat": "38.87",
                    "lon": "-86.69"
                },
                {
                    "lat": "38.75",
                    "lon": "-86.3"
                },
                {
                    "lat": "38.84",
                    "lon": "-87.16"
                }
            ],
            "Vertex_count": 7,
            "stormInfo": {
                "time_epoch": 1363464360,
                "Motion_deg": 243,
                "Motion_spd": 18,
                "position_lat": 38.90,
                "position_lon": -86.96
            }
        }
    }]
}

astronomy_response = {
    "response": {
        "version": "0.1",
        "termsofService": "http://www.wunderground.com/weather/api/d/terms.html",
        "features": {
            "astronomy": 1
        }
    },
    "moon_phase": {
        "percentIlluminated": "81",
        "ageOfMoon": "10",
        "current_time": {
            "hour": "9",
            "minute": "56"
        },
        "sunrise": {
            "hour": "7",
            "minute": "01"
        },
        "sunset": {
            "hour": "16",
            "minute": "56"
        }
    }
}

hurricane_response = {
    "response": {
        "version": "0.1",
        "termsofService": "http://www.wunderground.com/weather/api/d/terms.html",
        "features": {
            "currenthurricane": 1
        }
    },
    "currenthurricane": [{
        "stormInfo": {
            "stormName": "Daniel",
            "stormName_Nice": "Hurricane Daniel",
            "stormNumber": "ep201204"
        },
        "Current": {
            "lat": 15.4,
            "lon": -130.7,
            "SaffirSimpsonCategory": 1,
            "Category": "Hurricane",
            "Time": {
                "hour": "17",
                "hour_padded": "17",
                "year": "2012",
                "mon": "7",
                "mon_padded": "07",
                "mon_abbrev": "Jul",
                "mday": "9",
                "mday_padded": "09",
                "yday": "190",
                "isdst": "1",
                "epoch": "1341867600",
                "pretty": "5:00 PM EDT on July 09, 2012",
                "civil": "5:00 PM",
                "month_name": "July",
                "month_name_abbrev": "Jul",
                "weekday_name": "Monday",
                "weekday_name_night": "Monday Night",
                "weekday_name_abbrev": "Mon",
                "weekday_name_unlang": "Monday",
                "weekday_name_night_unlang": "Monday Night",
                "ampm": "PM"
            },
            "TimeGMT": {
                "hour": "21",
                "hour_padded": "21",
                "year": "2012",
                "mon": "7",
                "mon_padded": "07",
                "mon_abbrev": "Jul",
                "mday": "9",
                "mday_padded": "09",
                "yday": "190",
                "epoch": "1341867600",
                "pretty": "9:00 PM GMT on July 09, 2012",
                "civil": "9:00 PM",
                "month_name": "July",
                "month_name_abbrev": "Jul",
                "weekday_name": "Monday",
                "weekday_name_night": "Monday Night",
                "weekday_name_abbrev": "Mon",
                "weekday_name_unlang": "Monday",
                "weekday_name_night_unlang": "Monday Night",
                "ampm": "PM"
            },
            "WindSpeed": {
                "Kts": 65,
                "Mph": 75,
                "Kph": 120
            },
            "WindGust": {
                "Kts": 80,
                "Mph": 90,
                "Kph": 120
            },
            "Fspeed": {
                "Kts": 14,
                "Mph": 16,
                "Kph": 25
            },
            "Movement": {
                "Degrees": "275",
                "Text": "W"
            },
            "Pressure": {
                "mb": 992,
                "inches": 29.28
            },
            "WindQuadrants": {
                "comment": "Use these keys to determine what quadrants exist in the WindRadius object they could be N S E W (representing quadrants rotated 45 degrees x) or NE SE SW NW (representing the typical + quadrant system)",
                "quad_1": "NE",
                "quad_2": "SE",
                "quad_3": "SW",
                "quad_4": "NW"
            },
            "WindRadius": {
                "34": {
                    "NE": 90,
                    "SE": 60,
                    "SW": 60,
                    "NW": 90
                },
                "50": {
                    "NE": 40,
                    "SE": 30,
                    "SW": 30,
                    "NW": 40
                },
                "64": {
                    "NE": 20,
                    "SE": 0,
                    "SW": 0,
                    "NW": 20
                }
            },
            "SeaQuadrants": {
                "comment": "Use these keys to determine what quadrants exist in the SeaRadius object they could be N S E W (representing quadrants rotated 45 degrees x) or NE SE SW NW (representing the typical + quadrant system)",
                "quad_1": "NE",
                "quad_2": "SE",
                "quad_3": "SW",
                "quad_4": "NW"
            },
            "SeaRadius": {
                "12": {
                    "NE": 180,
                    "SE": 75,
                    "SW": 90,
                    "NW": 150
                }
            }
        },
        "forecast": [{
            "ForecastHour": "12HR",
            "SaffirSimpsonCategory": 0,
            "lat": 15.5,
            "lon": -133.0,
            "Category": "Tropical Storm",
            "Time": {
                "hour": "2",
                "hour_padded": "02",
                "year": "2012",
                "mon": "7",
                "mon_padded": "07",
                "mon_abbrev": "Jul",
                "mday": "10",
                "mday_padded": "10",
                "yday": "191",
                "isdst": "1",
                "epoch": "1341900000",
                "pretty": "2:00 AM EDT on July 10, 2012",
                "civil": "2:00 AM",
                "month_name": "July",
                "month_name_abbrev": "Jul",
                "weekday_name": "Tuesday",
                "weekday_name_night": "Tuesday Night",
                "weekday_name_abbrev": "Tue",
                "weekday_name_unlang": "Tuesday",
                "weekday_name_night_unlang": "Tuesday Night",
                "ampm": "AM"
            },
            "TimeGMT": {
                "hour": "6",
                "hour_padded": "06",
                "year": "2012",
                "mon": "7",
                "mon_padded": "07",
                "mon_abbrev": "Jul",
                "mday": "10",
                "mday_padded": "10",
                "yday": "191",
                "epoch": "1341900000",
                "pretty": "6:00 AM GMT on July 10, 2012",
                "civil": "6:00 AM",
                "month_name": "July",
                "month_name_abbrev": "Jul",
                "weekday_name": "Tuesday",
                "weekday_name_night": "Tuesday Night",
                "weekday_name_abbrev": "Tue",
                "weekday_name_unlang": "Tuesday",
                "weekday_name_night_unlang": "Tuesday Night",
                "ampm": "AM"
            },
            "WindSpeed": {
                "Kts": 55,
                "Mph": 65,
                "Kph": 100
            },
            "WindGust": {
                "Kts": 65,
                "Mph": 75,
                "Kph": 120
            },
            "WindQuadrants": {
                "comment": "Use these keys to determine what quadrants exist in the WindRadius object they could be N S E W (representing quadrants rotated 45 degrees x) or NE SE SW NW (representing the typical + quadrant system)",
                "quad_1": "NE",
                "quad_2": "SE",
                "quad_3": "SW",
                "quad_4": "NW"
            },
            "WindRadius": {
                "34": {
                    "NE": 80,
                    "SE": 50,
                    "SW": 50,
                    "NW": 80
                },
                "50": {
                    "NE": 30,
                    "SE": 0,
                    "SW": 0,
                    "NW": 30
                },
                "64": {
                    "NE": 'null',
                    "SE": 'null',
                    "SW": 'null',
                    "NW": 'null'
                }
            }
        }, {
            "ForecastHour": "24HR",
            "SaffirSimpsonCategory": 0,
            "lat": 15.5,
            "lon": -136.0,
            "Category": "Tropical Storm",
            "Time": {
                "hour": "14",
                "hour_padded": "14",
                "year": "2012",
                "mon": "7",
                "mon_padded": "07",
                "mon_abbrev": "Jul",
                "mday": "10",
                "mday_padded": "10",
                "yday": "191",
                "isdst": "1",
                "epoch": "1341943200",
                "pretty": "2:00 PM EDT on July 10, 2012",
                "civil": "2:00 PM",
                "month_name": "July",
                "month_name_abbrev": "Jul",
                "weekday_name": "Tuesday",
                "weekday_name_night": "Tuesday Night",
                "weekday_name_abbrev": "Tue",
                "weekday_name_unlang": "Tuesday",
                "weekday_name_night_unlang": "Tuesday Night",
                "ampm": "PM"
            },
            "TimeGMT": {
                "hour": "18",
                "hour_padded": "18",
                "year": "2012",
                "mon": "7",
                "mon_padded": "07",
                "mon_abbrev": "Jul",
                "mday": "10",
                "mday_padded": "10",
                "yday": "191",
                "epoch": "1341943200",
                "pretty": "6:00 PM GMT on July 10, 2012",
                "civil": "6:00 PM",
                "month_name": "July",
                "month_name_abbrev": "Jul",
                "weekday_name": "Tuesday",
                "weekday_name_night": "Tuesday Night",
                "weekday_name_abbrev": "Tue",
                "weekday_name_unlang": "Tuesday",
                "weekday_name_night_unlang": "Tuesday Night",
                "ampm": "PM"
            },
            "WindSpeed": {
                "Kts": 45,
                "Mph": 50,
                "Kph": 85
            },
            "WindGust": {
                "Kts": 55,
                "Mph": 65,
                "Kph": 100
            },
            "WindQuadrants": {
                "comment": "Use these keys to determine what quadrants exist in the WindRadius object they could be N S E W (representing quadrants rotated 45 degrees x) or NE SE SW NW (representing the typical + quadrant system)",
                "quad_1": "NE",
                "quad_2": "SE",
                "quad_3": "SW",
                "quad_4": "NW"
            },
            "WindRadius": {
                "34": {
                    "NE": 60,
                    "SE": 40,
                    "SW": 40,
                    "NW": 60
                },
                "50": {
                    "NE": 'null',
                    "SE": 'null',
                    "SW": 'null',
                    "NW": 'null'
                },
                "64": {
                    "NE": 'null',
                    "SE": 'null',
                    "SW": 'null',
                    "NW": 'null'
                }
            }
        },
        ],
        "ExtendedForecast": [{
            "ForecastHour": "4DAY",
        },
        ],
        "track": ['...']
    }]
}

geolookup_response = {
    "response": {
        "version": "0.1",
        "termsofService": "http://www.wunderground.com/weather/api/d/terms.html",
        "features": {
            "geolookup": 1
        }
    },
    "location": {
        "type": "CITY",
        "country": "US",
        "country_iso3166": "US",
        "country_name": "USA",
        "state": "CA",
        "city": "San Francisco",
        "tz_short": "PDT",
        "tz_long": "America/Los_Angeles",
        "lat": "37.77500916",
        "lon": "-122.41825867",
        "zip": "94101",
        "magic": "1",
        "wmo": "99999",
        "l": "/q/zmw:94101.1.99999",
        "requesturl": "US/CA/San_Francisco.html",
        "wuiurl": "https://www.wunderground.com/US/CA/San_Francisco.html",
        "nearby_weather_stations": {
            "airport": {
                "station": [{
                  "city": "San Francisco",
                  "state": "CA",
                  "country": "US",
                  "icao": "KSFO",
                  "lat": "37.61999893",
                  "lon": "-122.37000275"
                }, {
                    "city": "Oakland",
                    "state": "CA",
                    "country": "US",
                    "icao": "KOAK",
                    "lat": "37.72000122",
                    "lon": "-122.22000122"
                }, {
                    "city": "Hayward",
                    "state": "CA",
                    "country": "US",
                    "icao": "KHWD",
                    "lat": "37.65999985",
                    "lon": "-122.12000275"
                }, {
                    "city": "Half Moon Bay",
                    "state": "CA",
                    "country": "US",
                    "icao": "KHAF",
                    "lat": "37.50999832",
                    "lon": "-122.50000000"
                }]
            },
            "pws": {
                "station": [{
                    "neighborhood": "SOMA - Near Van Ness",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR58",
                    "distance_km": 0,
                    "distance_mi": 0
                }, {
                    "neighborhood": "North Mission (Valencia & Market)",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR49",
                    "distance_km": 0,
                    "distance_mi": 0
                }, {
                    "neighborhood": "SOMA",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR131",
                    "distance_km": 0,
                    "distance_mi": 0
                }, {
                    "neighborhood": "HADS SAN FRANCISCO DOWNTOWN CA US",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "MSFOC1",
                    "distance_km": 1,
                    "distance_mi": 0
                }, {
                    "neighborhood": "SoMa",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR113",
                    "distance_km": 1,
                    "distance_mi": 1
                }, {
                    "neighborhood": "Mission Bay - My weather is better than yours.",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR53",
                    "distance_km": 1,
                    "distance_mi": 1
                }, {
                    "neighborhood": "Castro/San Francisco",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KPCASANF2",
                    "distance_km": 2,
                    "distance_mi": 1
                }, {
                    "neighborhood": "The Castro",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR114",
                    "distance_km": 2,
                    "distance_mi": 1
                }, {
                    "neighborhood": "China Basin Landing",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR14",
                    "distance_km": 2,
                    "distance_mi": 1
                }, {
                    "neighborhood": "The Mission: Even the weather is hip",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR79",
                    "distance_km": 2,
                    "distance_mi": 1
                }, {
                    "neighborhood": "Castro/Eureka Valley",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR138",
                    "distance_km": 2,
                    "distance_mi": 1
                }, {
                    "neighborhood": "Potrero Hill",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR108",
                    "distance_km": 2,
                    "distance_mi": 1
                }, {
                    "neighborhood": "Financial District",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR102",
                    "distance_km": 2,
                    "distance_mi": 1
                }, {
                    "neighborhood": "Noe Valley",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR86",
                    "distance_km": 2,
                    "distance_mi": 1
                }, {
                    "neighborhood": "APRSWXNET San Francisco CA US",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "MD9646",
                    "distance_km": 2,
                    "distance_mi": 1
                }, {
                    "neighborhood": "Noe Valley",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR3",
                    "distance_km": 2,
                    "distance_mi": 1
                }, {
                    "neighborhood": "Diamond Heights",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR76",
                    "distance_km": 3,
                    "distance_mi": 1
                }, {
                    "neighborhood": "Noe Valley (South)",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR98",
                    "distance_km": 3,
                    "distance_mi": 2
                }, {
                    "neighborhood": "Billy Goat Hill",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR73",
                    "distance_km": 3,
                    "distance_mi": 2
                }, {
                    "neighborhood": "Twin Peaks",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR34",
                    "distance_km": 4,
                    "distance_mi": 2
                }, {
                    "neighborhood": "APRSWXNET San Francisco CA US",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "MC9629",
                    "distance_km": 4,
                    "distance_mi": 2
                }, {
                    "neighborhood": "MesoWest San Fran Sewage Treatment Plant CA US CARB",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "MCQ147",
                    "distance_km": 4,
                    "distance_mi": 2
                }, {
                    "neighborhood": "Mid Richmond",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR128",
                    "distance_km": 4,
                    "distance_mi": 2
                }, {
                    "neighborhood": "Golden Gate Heights",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR46",
                    "distance_km": 4,
                    "distance_mi": 2
                }, {
                    "neighborhood": "Portola",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR135",
                    "distance_km": 5,
                    "distance_mi": 3
                }, {
                    "neighborhood": "Forest Hill",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR72",
                    "distance_km": 5,
                    "distance_mi": 3
                }, {
                    "neighborhood": "Sunnyside",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR70",
                    "distance_km": 5,
                    "distance_mi": 3
                }, {
                    "neighborhood": "West Portal",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR130",
                    "distance_km": 5,
                    "distance_mi": 3
                }, {
                    "neighborhood": "Forest Hill",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR48",
                    "distance_km": 5,
                    "distance_mi": 3
                }, {
                    "neighborhood": "Forest Hill",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR109",
                    "distance_km": 5,
                    "distance_mi": 3
                }, {
                    "neighborhood": "Sherwood Forest",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR129",
                    "distance_km": 5,
                    "distance_mi": 3
                }, {
                    "neighborhood": "Ocean Beach - Kellys Cove",
                    "city": "San Francisco",
                    "state": "CA",
                    "country": "US",
                    "id": "KCASANFR99",
                    "distance_km": 8,
                    "distance_mi": 4
                }]
            }
        }
    }
}

hourly_daycast_response = {
    "response": {
        "version": "0.1",
        "termsofService": "http://www.wunderground.com/weather/api/d/terms.html",
        "features": {
            "hourly": 1
        }
    },
    "hourly_forecast": [{
        "FCTTIME": {
            "hour": "11",
            "hour_padded": "11",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "3",
            "mday_padded": "03",
            "yday": "184",
            "isdst": "1",
            "epoch": "1341338400",
            "pretty": "11:00 AM PDT on July 03, 2012",
            "civil": "11:00 AM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Tuesday",
            "weekday_name_night": "Tuesday Night",
            "weekday_name_abbrev": "Tue",
            "weekday_name_unlang": "Tuesday",
            "weekday_name_night_unlang": "Tuesday Night",
            "ampm": "AM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "66",
            "metric": "19"
        },
        "dewpoint": {
            "english": "55",
            "metric": "13"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
        "fctcode": "1",
        "sky": "22",
        "wspd": {
            "english": "5",
            "metric": "8"
        },
        "wdir": {
            "dir": "West",
            "degrees": "260"
        },
        "wx": "",
        "uvi": "6",
        "humidity": "65",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "66",
            "metric": "19"
        },
        "qpf": {
            "english": "0.00",
            "metric": "0.00"
        },
        "snow": {
            "english": "0.00",
            "metric": "0.00"
        },
        "pop": "0",
        "mslp": {
            "english": "29.90",
            "metric": "1012"
        }
    }, {
        "FCTTIME": {
            "hour": "12",
            "hour_padded": "12",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "3",
            "mday_padded": "03",
            "yday": "184",
            "isdst": "1",
            "epoch": "1341342000",
            "pretty": "12:00 PM PDT on July 03, 2012",
            "civil": "12:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Tuesday",
            "weekday_name_night": "Tuesday Night",
            "weekday_name_abbrev": "Tue",
            "weekday_name_unlang": "Tuesday",
            "weekday_name_night_unlang": "Tuesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "67",
            "metric": "19"
        },
        "dewpoint": {
            "english": "55",
            "metric": "13"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
        "fctcode": "1",
        "sky": "22",
        "wspd": {
            "english": "9",
            "metric": "14"
        },
        "wdir": {
            "dir": "West",
            "degrees": "260"
        },
        "wx": "",
        "uvi": "6",
        "humidity": "64",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "67",
            "metric": "19"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.90",
            "metric": "1012"
        }
    }, {
        "FCTTIME": {
            "hour": "13",
            "hour_padded": "13",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "3",
            "mday_padded": "03",
            "yday": "184",
            "isdst": "1",
            "epoch": "1341345600",
            "pretty": "1:00 PM PDT on July 03, 2012",
            "civil": "1:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Tuesday",
            "weekday_name_night": "Tuesday Night",
            "weekday_name_abbrev": "Tue",
            "weekday_name_unlang": "Tuesday",
            "weekday_name_night_unlang": "Tuesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "67",
            "metric": "20"
        },
        "dewpoint": {
            "english": "55",
            "metric": "13"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
        "fctcode": "1",
        "sky": "22",
        "wspd": {
            "english": "13",
            "metric": "21"
        },
        "wdir": {
            "dir": "West",
            "degrees": "260"
        },
        "wx": "",
        "uvi": "6",
        "humidity": "63",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "67",
            "metric": "20"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.90",
            "metric": "1012"
        }
    }, {
        "FCTTIME": {
            "hour": "14",
            "hour_padded": "14",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "3",
            "mday_padded": "03",
            "yday": "184",
            "isdst": "1",
            "epoch": "1341349200",
            "pretty": "2:00 PM PDT on July 03, 2012",
            "civil": "2:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Tuesday",
            "weekday_name_night": "Tuesday Night",
            "weekday_name_abbrev": "Tue",
            "weekday_name_unlang": "Tuesday",
            "weekday_name_night_unlang": "Tuesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "68",
            "metric": "20"
        },
        "dewpoint": {
            "english": "55",
            "metric": "13"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
        "fctcode": "1",
        "sky": "22",
        "wspd": {
            "english": "17",
            "metric": "27"
        },
        "wdir": {
            "dir": "WSW",
            "degrees": "255"
        },
        "wx": "",
        "uvi": "7",
        "humidity": "62",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "68",
            "metric": "20"
        },
        "qpf": {
            "english": "0.00",
            "metric": "0.00"
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.87",
            "metric": "1011"
        }
    }, {
        "FCTTIME": {
            "hour": "15",
            "hour_padded": "15",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "3",
            "mday_padded": "03",
            "yday": "184",
            "isdst": "1",
            "epoch": "1341352800",
            "pretty": "3:00 PM PDT on July 03, 2012",
            "civil": "3:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Tuesday",
            "weekday_name_night": "Tuesday Night",
            "weekday_name_abbrev": "Tue",
            "weekday_name_unlang": "Tuesday",
            "weekday_name_night_unlang": "Tuesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "68",
            "metric": "20"
        },
        "dewpoint": {
            "english": "55",
            "metric": "13"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
        "fctcode": "1",
        "sky": "22",
        "wspd": {
            "english": "17",
            "metric": "27"
        },
        "wdir": {
            "dir": "WSW",
            "degrees": "255"
        },
        "wx": "",
        "uvi": "7",
        "humidity": "62",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "68",
            "metric": "20"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.87",
            "metric": "1011"
        }
    }, {
        "FCTTIME": {
            "hour": "16",
            "hour_padded": "16",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "3",
            "mday_padded": "03",
            "yday": "184",
            "isdst": "1",
            "epoch": "1341356400",
            "pretty": "4:00 PM PDT on July 03, 2012",
            "civil": "4:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Tuesday",
            "weekday_name_night": "Tuesday Night",
            "weekday_name_abbrev": "Tue",
            "weekday_name_unlang": "Tuesday",
            "weekday_name_night_unlang": "Tuesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "68",
            "metric": "20"
        },
        "dewpoint": {
            "english": "55",
            "metric": "13"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
        "fctcode": "1",
        "sky": "22",
        "wspd": {
            "english": "17",
            "metric": "27"
        },
        "wdir": {
            "dir": "WSW",
            "degrees": "255"
        },
        "wx": "",
        "uvi": "7",
        "humidity": "63",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "68",
            "metric": "20"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.87",
            "metric": "1011"
        }
    }, {
        "FCTTIME": {
            "hour": "17",
            "hour_padded": "17",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "3",
            "mday_padded": "03",
            "yday": "184",
            "isdst": "1",
            "epoch": "1341360000",
            "pretty": "5:00 PM PDT on July 03, 2012",
            "civil": "5:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Tuesday",
            "weekday_name_night": "Tuesday Night",
            "weekday_name_abbrev": "Tue",
            "weekday_name_unlang": "Tuesday",
            "weekday_name_night_unlang": "Tuesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "68",
            "metric": "20"
        },
        "dewpoint": {
            "english": "55",
            "metric": "13"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
        "fctcode": "1",
        "sky": "4",
        "wspd": {
            "english": "17",
            "metric": "27"
        },
        "wdir": {
            "dir": "WSW",
            "degrees": "247"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "63",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "68",
            "metric": "20"
        },
        "qpf": {
            "english": "0.00",
            "metric": "0.00"
        },
        "snow": {
            "english": "0.00",
            "metric": "0.00"
        },
        "pop": "0",
        "mslp": {
            "english": "29.82",
            "metric": "1009"
        }
    }, {
        "FCTTIME": {
            "hour": "18",
            "hour_padded": "18",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "3",
            "mday_padded": "03",
            "yday": "184",
            "isdst": "1",
            "epoch": "1341363600",
            "pretty": "6:00 PM PDT on July 03, 2012",
            "civil": "6:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Tuesday",
            "weekday_name_night": "Tuesday Night",
            "weekday_name_abbrev": "Tue",
            "weekday_name_unlang": "Tuesday",
            "weekday_name_night_unlang": "Tuesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "67",
            "metric": "20"
        },
        "dewpoint": {
            "english": "55",
            "metric": "13"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
        "fctcode": "1",
        "sky": "4",
        "wspd": {
            "english": "15",
            "metric": "24"
        },
        "wdir": {
            "dir": "WSW",
            "degrees": "247"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "63",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "67",
            "metric": "20"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.82",
            "metric": "1009"
        }
    }, {
        "FCTTIME": {
            "hour": "19",
            "hour_padded": "19",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "3",
            "mday_padded": "03",
            "yday": "184",
            "isdst": "1",
            "epoch": "1341367200",
            "pretty": "7:00 PM PDT on July 03, 2012",
            "civil": "7:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Tuesday",
            "weekday_name_night": "Tuesday Night",
            "weekday_name_abbrev": "Tue",
            "weekday_name_unlang": "Tuesday",
            "weekday_name_night_unlang": "Tuesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "67",
            "metric": "19"
        },
        "dewpoint": {
            "english": "54",
            "metric": "12"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
        "fctcode": "1",
        "sky": "4",
        "wspd": {
            "english": "13",
            "metric": "21"
        },
        "wdir": {
            "dir": "WSW",
            "degrees": "247"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "62",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "67",
            "metric": "19"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.82",
            "metric": "1009"
        }
    }, {
        "FCTTIME": {
            "hour": "20",
            "hour_padded": "20",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "3",
            "mday_padded": "03",
            "yday": "184",
            "isdst": "1",
            "epoch": "1341370800",
            "pretty": "8:00 PM PDT on July 03, 2012",
            "civil": "8:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Tuesday",
            "weekday_name_night": "Tuesday Night",
            "weekday_name_abbrev": "Tue",
            "weekday_name_unlang": "Tuesday",
            "weekday_name_night_unlang": "Tuesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "66",
            "metric": "19"
        },
        "dewpoint": {
            "english": "54",
            "metric": "12"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
        "fctcode": "1",
        "sky": "4",
        "wspd": {
            "english": "11",
            "metric": "18"
        },
        "wdir": {
            "dir": "WSW",
            "degrees": "248"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "62",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "66",
            "metric": "19"
        },
        "qpf": {
            "english": "0.00",
            "metric": "0.00"
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.81",
            "metric": "1009"
        }
    }, {
        "FCTTIME": {
            "hour": "21",
            "hour_padded": "21",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "3",
            "mday_padded": "03",
            "yday": "184",
            "isdst": "1",
            "epoch": "1341374400",
            "pretty": "9:00 PM PDT on July 03, 2012",
            "civil": "9:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Tuesday",
            "weekday_name_night": "Tuesday Night",
            "weekday_name_abbrev": "Tue",
            "weekday_name_unlang": "Tuesday",
            "weekday_name_night_unlang": "Tuesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "63",
            "metric": "17"
        },
        "dewpoint": {
            "english": "53",
            "metric": "12"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/nt_clear.gif",
        "fctcode": "1",
        "sky": "4",
        "wspd": {
            "english": "10",
            "metric": "17"
        },
        "wdir": {
            "dir": "WSW",
            "degrees": "248"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "68",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "63",
            "metric": "17"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.81",
            "metric": "1009"
        }
    }, {
        "FCTTIME": {
            "hour": "22",
            "hour_padded": "22",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "3",
            "mday_padded": "03",
            "yday": "184",
            "isdst": "1",
            "epoch": "1341378000",
            "pretty": "10:00 PM PDT on July 03, 2012",
            "civil": "10:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Tuesday",
            "weekday_name_night": "Tuesday Night",
            "weekday_name_abbrev": "Tue",
            "weekday_name_unlang": "Tuesday",
            "weekday_name_night_unlang": "Tuesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "60",
            "metric": "16"
        },
        "dewpoint": {
            "english": "53",
            "metric": "11"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/nt_clear.gif",
        "fctcode": "1",
        "sky": "4",
        "wspd": {
            "english": "10",
            "metric": "15"
        },
        "wdir": {
            "dir": "WSW",
            "degrees": "248"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "75",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "60",
            "metric": "16"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.81",
            "metric": "1009"
        }
    }, {
        "FCTTIME": {
            "hour": "23",
            "hour_padded": "23",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "3",
            "mday_padded": "03",
            "yday": "184",
            "isdst": "1",
            "epoch": "1341381600",
            "pretty": "11:00 PM PDT on July 03, 2012",
            "civil": "11:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Tuesday",
            "weekday_name_night": "Tuesday Night",
            "weekday_name_abbrev": "Tue",
            "weekday_name_unlang": "Tuesday",
            "weekday_name_night_unlang": "Tuesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "57",
            "metric": "14"
        },
        "dewpoint": {
            "english": "52",
            "metric": "11"
        },
        "condition": "Mostly Cloudy",
        "icon": "mostlycloudy",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/nt_mostlycloudy.gif",
        "fctcode": "3",
        "sky": "87",
        "wspd": {
            "english": "9",
            "metric": "14"
        },
        "wdir": {
            "dir": "SSW",
            "degrees": "211"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "81",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "57",
            "metric": "14"
        },
        "qpf": {
            "english": "0.00",
            "metric": "0.00"
        },
        "snow": {
            "english": "0.00",
            "metric": "0.00"
        },
        "pop": "0",
        "mslp": {
            "english": "29.84",
            "metric": "1010"
        }
    }, {
        "FCTTIME": {
            "hour": "0",
            "hour_padded": "00",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341385200",
            "pretty": "12:00 AM PDT on July 04, 2012",
            "civil": "12:00 AM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "AM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "57",
            "metric": "14"
        },
        "dewpoint": {
            "english": "52",
            "metric": "11"
        },
        "condition": "Mostly Cloudy",
        "icon": "mostlycloudy",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/nt_mostlycloudy.gif",
        "fctcode": "3",
        "sky": "87",
        "wspd": {
            "english": "9",
            "metric": "14"
        },
        "wdir": {
            "dir": "SSW",
            "degrees": "211"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "81",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "57",
            "metric": "14"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.84",
            "metric": "1010"
        }
    }, {
        "FCTTIME": {
            "hour": "1",
            "hour_padded": "01",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341388800",
            "pretty": "1:00 AM PDT on July 04, 2012",
            "civil": "1:00 AM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "AM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "57",
            "metric": "14"
        },
        "dewpoint": {
            "english": "52",
            "metric": "11"
        },
        "condition": "Mostly Cloudy",
        "icon": "mostlycloudy",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/nt_mostlycloudy.gif",
        "fctcode": "3",
        "sky": "87",
        "wspd": {
            "english": "9",
            "metric": "14"
        },
        "wdir": {
            "dir": "SSW",
            "degrees": "211"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "80",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "57",
            "metric": "14"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.84",
            "metric": "1010"
        }
    }, {
        "FCTTIME": {
            "hour": "2",
            "hour_padded": "02",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341392400",
            "pretty": "2:00 AM PDT on July 04, 2012",
            "civil": "2:00 AM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "AM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "57",
            "metric": "14"
        },
        "dewpoint": {
            "english": "52",
            "metric": "11"
        },
        "condition": "Mostly Cloudy",
        "icon": "mostlycloudy",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/nt_mostlycloudy.gif",
        "fctcode": "3",
        "sky": "87",
        "wspd": {
            "english": "9",
            "metric": "14"
        },
        "wdir": {
            "dir": "SSW",
            "degrees": "210"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "80",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "57",
            "metric": "14"
        },
        "qpf": {
            "english": "0.00",
            "metric": "0.00"
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.81",
            "metric": "1009"
        }
    }, {
        "FCTTIME": {
            "hour": "3",
            "hour_padded": "03",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341396000",
            "pretty": "3:00 AM PDT on July 04, 2012",
            "civil": "3:00 AM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "AM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "56",
            "metric": "14"
        },
        "dewpoint": {
            "english": "51",
            "metric": "11"
        },
        "condition": "Mostly Cloudy",
        "icon": "mostlycloudy",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/nt_mostlycloudy.gif",
        "fctcode": "3",
        "sky": "87",
        "wspd": {
            "english": "9",
            "metric": "14"
        },
        "wdir": {
            "dir": "SSW",
            "degrees": "210"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "80",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "56",
            "metric": "14"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.81",
            "metric": "1009"
        }
    }, {
        "FCTTIME": {
            "hour": "4",
            "hour_padded": "04",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341399600",
            "pretty": "4:00 AM PDT on July 04, 2012",
            "civil": "4:00 AM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "AM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "56",
            "metric": "13"
        },
        "dewpoint": {
            "english": "51",
            "metric": "10"
        },
        "condition": "Mostly Cloudy",
        "icon": "mostlycloudy",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/nt_mostlycloudy.gif",
        "fctcode": "3",
        "sky": "87",
        "wspd": {
            "english": "8",
            "metric": "13"
        },
        "wdir": {
            "dir": "SSW",
            "degrees": "210"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "80",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "56",
            "metric": "13"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.81",
            "metric": "1009"
        }
    }, {
        "FCTTIME": {
            "hour": "5",
            "hour_padded": "05",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341403200",
            "pretty": "5:00 AM PDT on July 04, 2012",
            "civil": "5:00 AM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "AM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "55",
            "metric": "13"
        },
        "dewpoint": {
            "english": "50",
            "metric": "10"
        },
        "condition": "Mostly Cloudy",
        "icon": "mostlycloudy",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/nt_mostlycloudy.gif",
        "fctcode": "3",
        "sky": "85",
        "wspd": {
            "english": "8",
            "metric": "13"
        },
        "wdir": {
            "dir": "SSW",
            "degrees": "202"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "80",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "55",
            "metric": "13"
        },
        "qpf": {
            "english": "0.00",
            "metric": "0.00"
        },
        "snow": {
            "english": "0.00",
            "metric": "0.00"
        },
        "pop": "0",
        "mslp": {
            "english": "29.80",
            "metric": "1009"
        }
    }, {
        "FCTTIME": {
            "hour": "6",
            "hour_padded": "06",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341406800",
            "pretty": "6:00 AM PDT on July 04, 2012",
            "civil": "6:00 AM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "AM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "56",
            "metric": "14"
        },
        "dewpoint": {
            "english": "51",
            "metric": "10"
        },
        "condition": "Mostly Cloudy",
        "icon": "mostlycloudy",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/mostlycloudy.gif",
        "fctcode": "3",
        "sky": "85",
        "wspd": {
            "english": "8",
            "metric": "13"
        },
        "wdir": {
            "dir": "SSW",
            "degrees": "202"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "80",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "56",
            "metric": "14"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.80",
            "metric": "1009"
        }
    }, {
        "FCTTIME": {
            "hour": "7",
            "hour_padded": "07",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341410400",
            "pretty": "7:00 AM PDT on July 04, 2012",
            "civil": "7:00 AM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "AM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "58",
            "metric": "14"
        },
        "dewpoint": {
            "english": "51",
            "metric": "11"
        },
        "condition": "Mostly Cloudy",
        "icon": "mostlycloudy",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/mostlycloudy.gif",
        "fctcode": "3",
        "sky": "85",
        "wspd": {
            "english": "8",
            "metric": "13"
        },
        "wdir": {
            "dir": "SSW",
            "degrees": "202"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "80",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "58",
            "metric": "14"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.80",
            "metric": "1009"
        }
    }, {
        "FCTTIME": {
            "hour": "8",
            "hour_padded": "08",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341414000",
            "pretty": "8:00 AM PDT on July 04, 2012",
            "civil": "8:00 AM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "AM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "59",
            "metric": "15"
        },
        "dewpoint": {
            "english": "52",
            "metric": "11"
        },
        "condition": "Mostly Cloudy",
        "icon": "mostlycloudy",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/mostlycloudy.gif",
        "fctcode": "3",
        "sky": "85",
        "wspd": {
            "english": "8",
            "metric": "13"
        },
        "wdir": {
            "dir": "SSW",
            "degrees": "203"
        },
        "wx": "",
        "uvi": "1",
        "humidity": "80",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "59",
            "metric": "15"
        },
        "qpf": {
            "english": "0.00",
            "metric": "0.00"
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.82",
            "metric": "1009"
        }
    }, {
        "FCTTIME": {
            "hour": "9",
            "hour_padded": "09",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341417600",
            "pretty": "9:00 AM PDT on July 04, 2012",
            "civil": "9:00 AM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "AM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "63",
            "metric": "17"
        },
        "dewpoint": {
            "english": "53",
            "metric": "11"
        },
        "condition": "Mostly Cloudy",
        "icon": "mostlycloudy",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/mostlycloudy.gif",
        "fctcode": "3",
        "sky": "85",
        "wspd": {
            "english": "9",
            "metric": "15"
        },
        "wdir": {
            "dir": "SSW",
            "degrees": "203"
        },
        "wx": "",
        "uvi": "1",
        "humidity": "71",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "63",
            "metric": "17"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.82",
            "metric": "1009"
        }
    }, {
        "FCTTIME": {
            "hour": "10",
            "hour_padded": "10",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341421200",
            "pretty": "10:00 AM PDT on July 04, 2012",
            "civil": "10:00 AM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "AM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "68",
            "metric": "20"
        },
        "dewpoint": {
            "english": "53",
            "metric": "12"
        },
        "condition": "Mostly Cloudy",
        "icon": "mostlycloudy",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/mostlycloudy.gif",
        "fctcode": "3",
        "sky": "85",
        "wspd": {
            "english": "11",
            "metric": "17"
        },
        "wdir": {
            "dir": "SSW",
            "degrees": "203"
        },
        "wx": "",
        "uvi": "1",
        "humidity": "63",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "68",
            "metric": "20"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.82",
            "metric": "1009"
        }
    }, {
        "FCTTIME": {
            "hour": "11",
            "hour_padded": "11",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341424800",
            "pretty": "11:00 AM PDT on July 04, 2012",
            "civil": "11:00 AM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "AM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "72",
            "metric": "22"
        },
        "dewpoint": {
            "english": "54",
            "metric": "12"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
        "fctcode": "1",
        "sky": "20",
        "wspd": {
            "english": "12",
            "metric": "19"
        },
        "wdir": {
            "dir": "SW",
            "degrees": "231"
        },
        "wx": "",
        "uvi": "6",
        "humidity": "54",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "72",
            "metric": "22"
        },
        "qpf": {
            "english": "0.00",
            "metric": "0.00"
        },
        "snow": {
            "english": "0.00",
            "metric": "0.00"
        },
        "pop": "0",
        "mslp": {
            "english": "29.84",
            "metric": "1010"
        }
    }, {
        "FCTTIME": {
            "hour": "12",
            "hour_padded": "12",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341428400",
            "pretty": "12:00 PM PDT on July 04, 2012",
            "civil": "12:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "71",
            "metric": "21"
        },
        "dewpoint": {
            "english": "54",
            "metric": "12"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
        "fctcode": "1",
        "sky": "20",
        "wspd": {
            "english": "13",
            "metric": "21"
        },
        "wdir": {
            "dir": "SW",
            "degrees": "231"
        },
        "wx": "",
        "uvi": "6",
        "humidity": "56",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "71",
            "metric": "21"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.84",
            "metric": "1010"
        }
    }, {
        "FCTTIME": {
            "hour": "13",
            "hour_padded": "13",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341432000",
            "pretty": "1:00 PM PDT on July 04, 2012",
            "civil": "1:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "69",
            "metric": "21"
        },
        "dewpoint": {
            "english": "54",
            "metric": "12"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
        "fctcode": "1",
        "sky": "20",
        "wspd": {
            "english": "14",
            "metric": "22"
        },
        "wdir": {
            "dir": "SW",
            "degrees": "231"
        },
        "wx": "",
        "uvi": "6",
        "humidity": "59",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "69",
            "metric": "21"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.84",
            "metric": "1010"
        }
    }, {
        "FCTTIME": {
            "hour": "14",
            "hour_padded": "14",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341435600",
            "pretty": "2:00 PM PDT on July 04, 2012",
            "civil": "2:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "68",
            "metric": "20"
        },
        "dewpoint": {
            "english": "54",
            "metric": "12"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
        "fctcode": "1",
        "sky": "20",
        "wspd": {
            "english": "15",
            "metric": "24"
        },
        "wdir": {
            "dir": "WSW",
            "degrees": "237"
        },
        "wx": "",
        "uvi": "7",
        "humidity": "61",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "68",
            "metric": "20"
        },
        "qpf": {
            "english": "0.00",
            "metric": "0.00"
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.83",
            "metric": "1010"
        }
    }, {
        "FCTTIME": {
            "hour": "15",
            "hour_padded": "15",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341439200",
            "pretty": "3:00 PM PDT on July 04, 2012",
            "civil": "3:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "67",
            "metric": "20"
        },
        "dewpoint": {
            "english": "54",
            "metric": "12"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
        "fctcode": "1",
        "sky": "20",
        "wspd": {
            "english": "14",
            "metric": "22"
        },
        "wdir": {
            "dir": "WSW",
            "degrees": "237"
        },
        "wx": "",
        "uvi": "7",
        "humidity": "62",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "67",
            "metric": "20"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.83",
            "metric": "1010"
        }
    }, {
        "FCTTIME": {
            "hour": "16",
            "hour_padded": "16",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341442800",
            "pretty": "4:00 PM PDT on July 04, 2012",
            "civil": "4:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "67",
            "metric": "19"
        },
        "dewpoint": {
            "english": "54",
            "metric": "12"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
        "fctcode": "1",
        "sky": "20",
        "wspd": {
            "english": "13",
            "metric": "21"
        },
        "wdir": {
            "dir": "WSW",
            "degrees": "237"
        },
        "wx": "",
        "uvi": "7",
        "humidity": "64",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "67",
            "metric": "19"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.83",
            "metric": "1010"
        }
    }, {
        "FCTTIME": {
            "hour": "17",
            "hour_padded": "17",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341446400",
            "pretty": "5:00 PM PDT on July 04, 2012",
            "civil": "5:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "66",
            "metric": "19"
        },
        "dewpoint": {
            "english": "54",
            "metric": "12"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
        "fctcode": "1",
        "sky": "16",
        "wspd": {
            "english": "12",
            "metric": "19"
        },
        "wdir": {
            "dir": "WSW",
            "degrees": "237"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "65",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "66",
            "metric": "19"
        },
        "qpf": {
            "english": "0.00",
            "metric": "0.00"
        },
        "snow": {
            "english": "0.00",
            "metric": "0.00"
        },
        "pop": "0",
        "mslp": {
            "english": "29.82",
            "metric": "1009"
        }
    }, {
        "FCTTIME": {
            "hour": "18",
            "hour_padded": "18",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341450000",
            "pretty": "6:00 PM PDT on July 04, 2012",
            "civil": "6:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "65",
            "metric": "18"
        },
        "dewpoint": {
            "english": "54",
            "metric": "12"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
        "fctcode": "1",
        "sky": "16",
        "wspd": {
            "english": "12",
            "metric": "19"
        },
        "wdir": {
            "dir": "WSW",
            "degrees": "237"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "68",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "65",
            "metric": "18"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.82",
            "metric": "1009"
        }
    }, {
        "FCTTIME": {
            "hour": "19",
            "hour_padded": "19",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341453600",
            "pretty": "7:00 PM PDT on July 04, 2012",
            "civil": "7:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "64",
            "metric": "18"
        },
        "dewpoint": {
            "english": "54",
            "metric": "12"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
        "fctcode": "1",
        "sky": "16",
        "wspd": {
            "english": "12",
            "metric": "19"
        },
        "wdir": {
            "dir": "WSW",
            "degrees": "237"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "72",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "64",
            "metric": "18"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.82",
            "metric": "1009"
        }
    }, {
        "FCTTIME": {
            "hour": "20",
            "hour_padded": "20",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341457200",
            "pretty": "8:00 PM PDT on July 04, 2012",
            "civil": "8:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "63",
            "metric": "17"
        },
        "dewpoint": {
            "english": "54",
            "metric": "12"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/clear.gif",
        "fctcode": "1",
        "sky": "16",
        "wspd": {
            "english": "12",
            "metric": "19"
        },
        "wdir": {
            "dir": "WSW",
            "degrees": "237"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "75",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "63",
            "metric": "17"
        },
        "qpf": {
            "english": "0.00",
            "metric": "0.00"
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.84",
            "metric": "1010"
        }
    }, {
        "FCTTIME": {
            "hour": "21",
            "hour_padded": "21",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341460800",
            "pretty": "9:00 PM PDT on July 04, 2012",
            "civil": "9:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "61",
            "metric": "16"
        },
        "dewpoint": {
            "english": "54",
            "metric": "12"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/nt_clear.gif",
        "fctcode": "1",
        "sky": "16",
        "wspd": {
            "english": "12",
            "metric": "19"
        },
        "wdir": {
            "dir": "WSW",
            "degrees": "237"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "80",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "61",
            "metric": "16"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.84",
            "metric": "1010"
        }
    }, {
        "FCTTIME": {
            "hour": "22",
            "hour_padded": "22",
            "min": "00",
            "sec": "0",
            "year": "2012",
            "mon": "7",
            "mon_padded": "07",
            "mon_abbrev": "Jul",
            "mday": "4",
            "mday_padded": "04",
            "yday": "185",
            "isdst": "1",
            "epoch": "1341464400",
            "pretty": "10:00 PM PDT on July 04, 2012",
            "civil": "10:00 PM",
            "month_name": "July",
            "month_name_abbrev": "Jul",
            "weekday_name": "Wednesday",
            "weekday_name_night": "Wednesday Night",
            "weekday_name_abbrev": "Wed",
            "weekday_name_unlang": "Wednesday",
            "weekday_name_night_unlang": "Wednesday Night",
            "ampm": "PM",
            "tz": "",
            "age": ""
        },
        "temp": {
            "english": "59",
            "metric": "15"
        },
        "dewpoint": {
            "english": "54",
            "metric": "12"
        },
        "condition": "Clear",
        "icon": "clear",
        "icon_url": "http://icons-ak.wxug.com/i/c/k/nt_clear.gif",
        "fctcode": "1",
        "sky": "16",
        "wspd": {
            "english": "11",
            "metric": "18"
        },
        "wdir": {
            "dir": "WSW",
            "degrees": "237"
        },
        "wx": "",
        "uvi": "0",
        "humidity": "84",
        "windchill": {
            "english": "-9998",
            "metric": "-9998"
        },
        "heatindex": {
            "english": "-9998",
            "metric": "-9998"
        },
        "feelslike": {
            "english": "59",
            "metric": "15"
        },
        "qpf": {
            "english": "",
            "metric": ""
        },
        "snow": {
            "english": "",
            "metric": ""
        },
        "pop": "0",
        "mslp": {
            "english": "29.84",
            "metric": "1010"
        }
    }]
}

rawtide_response = {
    "response": {
        "version": "0.1",
        "termsofService": "http://www.wunderground.com/weather/api/d/terms.html",
        "features": {
            "rawtide": 1
        }
    },
    "rawtide": {
        "tideInfo": [{
            "tideSite": "Newport Beach, Newport Bay Entrance, Corona del Mar, California",
            "lat": "33.6033",
            "lon": "-117.883",
            "units": "feet",
            "type": "tide",
            "tzname": "America/Los_Angeles"
        }],
        "rawTideObs": [{
            "epoch": 1341355282,
            "height": 1.818341
        }, {
            "epoch": 1341355582,
            "height": 1.841344
        },
            {
            "epoch": 1341700282,
            "height": 3.544220
        }, {
            "epoch": 1341700582,
            "height": 3.484692
        }],
        "rawTideStats": [{
            "maxheight": 6.874717,
            "minheight": -1.447848
        }]
    }
}

tide_response = {
    "response": {
        "version": "0.1",
        "termsofService": "http://www.wunderground.com/weather/api/d/terms.html",
        "features": {
            "tide": 1
        }
    },
    "tide": {
        "tideInfo": [{
            "tideSite": "Newport Beach, Newport Bay Entrance, Corona del Mar, California",
            "lat": "33.6033",
            "lon": "-117.883",
            "units": "feet",
            "type": "tide",
            "tzname": "America/Los_Angeles"
        }],
        "tideSummary": [{
            "date": {
                "pretty": "2:51 PM EDT on July 03, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "03",
                "hour": "14",
                "min": "51",
                "tzname": "America/New_York",
                "epoch": "1341341506"
            },
            "utcdate": {
                "pretty": "6:51 PM GMT on July 03, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "03",
                "hour": "18",
                "min": "51",
                "tzname": "UTC",
                "epoch": "1341341506"
            },
            "data": {
                "height": "",
                "type": "Full Moon"
            }
        }, {
            "date": {
                "pretty": "6:13 PM EDT on July 03, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "03",
                "hour": "18",
                "min": "13",
                "tzname": "America/New_York",
                "epoch": "1341353605"
            },
            "utcdate": {
                "pretty": "10:13 PM GMT on July 03, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "03",
                "hour": "22",
                "min": "13",
                "tzname": "UTC",
                "epoch": "1341353605"
            },
            "data": {
                "height": "1.76 ft",
                "type": "Low Tide"
            }
        }, {
            "date": {
                "pretty": "11:05 PM EDT on July 03, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "03",
                "hour": "23",
                "min": "05",
                "tzname": "America/New_York",
                "epoch": "1341371130"
            },
            "utcdate": {
                "pretty": "3:05 AM GMT on July 04, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "04",
                "hour": "03",
                "min": "05",
                "tzname": "UTC",
                "epoch": "1341371130"
            },
            "data": {
                "height": "",
                "type": "Sunset"
            }
        }, {
            "date": {
                "pretty": "11:07 PM EDT on July 03, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "03",
                "hour": "23",
                "min": "07",
                "tzname": "America/New_York",
                "epoch": "1341371264"
            },
            "utcdate": {
                "pretty": "3:07 AM GMT on July 04, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "04",
                "hour": "03",
                "min": "07",
                "tzname": "UTC",
                "epoch": "1341371264"
            },
            "data": {
                "height": "",
                "type": "Moonrise"
            }
        }, {
            "date": {
                "pretty": "12:30 AM EDT on July 04, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "04",
                "hour": "00",
                "min": "30",
                "tzname": "America/New_York",
                "epoch": "1341376227"
            },
            "utcdate": {
                "pretty": "4:30 AM GMT on July 04, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "04",
                "hour": "04",
                "min": "30",
                "tzname": "UTC",
                "epoch": "1341376227"
            },
            "data": {
                "height": "6.87 ft",
                "type": "High Tide"
            }
        }, {
            "date": {
                "pretty": "7:40 AM EDT on July 04, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "04",
                "hour": "07",
                "min": "40",
                "tzname": "America/New_York",
                "epoch": "1341402005"
            },
            "utcdate": {
                "pretty": "11:40 AM GMT on July 04, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "04",
                "hour": "11",
                "min": "40",
                "tzname": "UTC",
                "epoch": "1341402005"
            },
            "data": {
                "height": "-1.45 ft",
                "type": "Low Tide"
            }
        }, {
            "date": {
                "pretty": "8:46 AM EDT on July 04, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "04",
                "hour": "08",
                "min": "46",
                "tzname": "America/New_York",
                "epoch": "1341405996"
            },
            "utcdate": {
                "pretty": "12:46 PM GMT on July 04, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "04",
                "hour": "12",
                "min": "46",
                "tzname": "UTC",
                "epoch": "1341405996"
            },
            "data": {
                "height": "",
                "type": "Sunrise"
            }
        }, {
            "date": {
                "pretty": "9:49 AM EDT on July 04, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "04",
                "hour": "09",
                "min": "49",
                "tzname": "America/New_York",
                "epoch": "1341409784"
            },
            "utcdate": {
                "pretty": "1:49 PM GMT on July 04, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "04",
                "hour": "13",
                "min": "49",
                "tzname": "UTC",
                "epoch": "1341409784"
            },
            "data": {
                "height": "",
                "type": "Moonset"
            }
        }, {
            "date": {
                "pretty": "2:05 PM EDT on July 04, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "04",
                "hour": "14",
                "min": "05",
                "tzname": "America/New_York",
                "epoch": "1341425125"
            },
            "utcdate": {
                "pretty": "6:05 PM GMT on July 04, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "04",
                "hour": "18",
                "min": "05",
                "tzname": "UTC",
                "epoch": "1341425125"
            },
            "data": {
                "height": "4.31 ft",
                "type": "High Tide"
            }
        }, {
            "date": {
                "pretty": "7:03 PM EDT on July 04, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "04",
                "hour": "19",
                "min": "03",
                "tzname": "America/New_York",
                "epoch": "1341443003"
            },
            "utcdate": {
                "pretty": "11:03 PM GMT on July 04, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "04",
                "hour": "23",
                "min": "03",
                "tzname": "UTC",
                "epoch": "1341443003"
            },
            "data": {
                "height": "1.72 ft",
                "type": "Low Tide"
            }
        }, {
            "date": {
                "pretty": "11:05 PM EDT on July 04, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "04",
                "hour": "23",
                "min": "05",
                "tzname": "America/New_York",
                "epoch": "1341457523"
            },
            "utcdate": {
                "pretty": "3:05 AM GMT on July 05, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "05",
                "hour": "03",
                "min": "05",
                "tzname": "UTC",
                "epoch": "1341457523"
            },
            "data": {
                "height": "",
                "type": "Sunset"
            }
        }, {
            "date": {
                "pretty": "11:53 PM EDT on July 04, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "04",
                "hour": "23",
                "min": "53",
                "tzname": "America/New_York",
                "epoch": "1341460416"
            },
            "utcdate": {
                "pretty": "3:53 AM GMT on July 05, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "05",
                "hour": "03",
                "min": "53",
                "tzname": "UTC",
                "epoch": "1341460416"
            },
            "data": {
                "height": "",
                "type": "Moonrise"
            }
        }, {
            "date": {
                "pretty": "1:16 AM EDT on July 05, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "05",
                "hour": "01",
                "min": "16",
                "tzname": "America/New_York",
                "epoch": "1341465365"
            },
            "utcdate": {
                "pretty": "5:16 AM GMT on July 05, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "05",
                "hour": "05",
                "min": "16",
                "tzname": "UTC",
                "epoch": "1341465365"
            },
            "data": {
                "height": "6.61 ft",
                "type": "High Tide"
            }
        }, {
            "date": {
                "pretty": "8:21 AM EDT on July 05, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "05",
                "hour": "08",
                "min": "21",
                "tzname": "America/New_York",
                "epoch": "1341490875"
            },
            "utcdate": {
                "pretty": "12:21 PM GMT on July 05, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "05",
                "hour": "12",
                "min": "21",
                "tzname": "UTC",
                "epoch": "1341490875"
            },
            "data": {
                "height": "-1.20 ft",
                "type": "Low Tide"
            }
        }, {
            "date": {
                "pretty": "8:47 AM EDT on July 05, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "05",
                "hour": "08",
                "min": "47",
                "tzname": "America/New_York",
                "epoch": "1341492425"
            },
            "utcdate": {
                "pretty": "12:47 PM GMT on July 05, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "05",
                "hour": "12",
                "min": "47",
                "tzname": "UTC",
                "epoch": "1341492425"
            },
            "data": {
                "height": "",
                "type": "Sunrise"
            }
        }, {
            "date": {
                "pretty": "10:56 AM EDT on July 05, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "05",
                "hour": "10",
                "min": "56",
                "tzname": "America/New_York",
                "epoch": "1341500192"
            },
            "utcdate": {
                "pretty": "2:56 PM GMT on July 05, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "05",
                "hour": "14",
                "min": "56",
                "tzname": "UTC",
                "epoch": "1341500192"
            },
            "data": {
                "height": "",
                "type": "Moonset"
            }
        }, {
            "date": {
                "pretty": "2:47 PM EDT on July 05, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "05",
                "hour": "14",
                "min": "47",
                "tzname": "America/New_York",
                "epoch": "1341514059"
            },
            "utcdate": {
                "pretty": "6:47 PM GMT on July 05, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "05",
                "hour": "18",
                "min": "47",
                "tzname": "UTC",
                "epoch": "1341514059"
            },
            "data": {
                "height": "4.42 ft",
                "type": "High Tide"
            }
        }, {
            "date": {
                "pretty": "7:53 PM EDT on July 05, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "05",
                "hour": "19",
                "min": "53",
                "tzname": "America/New_York",
                "epoch": "1341532428"
            },
            "utcdate": {
                "pretty": "11:53 PM GMT on July 05, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "05",
                "hour": "23",
                "min": "53",
                "tzname": "UTC",
                "epoch": "1341532428"
            },
            "data": {
                "height": "1.75 ft",
                "type": "Low Tide"
            }
        }, {
            "date": {
                "pretty": "11:05 PM EDT on July 05, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "05",
                "hour": "23",
                "min": "05",
                "tzname": "America/New_York",
                "epoch": "1341543913"
            },
            "utcdate": {
                "pretty": "3:05 AM GMT on July 06, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "06",
                "hour": "03",
                "min": "05",
                "tzname": "UTC",
                "epoch": "1341543913"
            },
            "data": {
                "height": "",
                "type": "Sunset"
            }
        }, {
            "date": {
                "pretty": "12:33 AM EDT on July 06, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "06",
                "hour": "00",
                "min": "33",
                "tzname": "America/New_York",
                "epoch": "1341549215"
            },
            "utcdate": {
                "pretty": "4:33 AM GMT on July 06, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "06",
                "hour": "04",
                "min": "33",
                "tzname": "UTC",
                "epoch": "1341549215"
            },
            "data": {
                "height": "",
                "type": "Moonrise"
            }
        }, {
            "date": {
                "pretty": "2:01 AM EDT on July 06, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "06",
                "hour": "02",
                "min": "01",
                "tzname": "America/New_York",
                "epoch": "1341554471"
            },
            "utcdate": {
                "pretty": "6:01 AM GMT on July 06, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "06",
                "hour": "06",
                "min": "01",
                "tzname": "UTC",
                "epoch": "1341554471"
            },
            "data": {
                "height": "6.14 ft",
                "type": "High Tide"
            }
        }, {
            "date": {
                "pretty": "8:47 AM EDT on July 06, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "06",
                "hour": "08",
                "min": "47",
                "tzname": "America/New_York",
                "epoch": "1341578855"
            },
            "utcdate": {
                "pretty": "12:47 PM GMT on July 06, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "06",
                "hour": "12",
                "min": "47",
                "tzname": "UTC",
                "epoch": "1341578855"
            },
            "data": {
                "height": "",
                "type": "Sunrise"
            }
        }, {
            "date": {
                "pretty": "9:00 AM EDT on July 06, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "06",
                "hour": "09",
                "min": "00",
                "tzname": "America/New_York",
                "epoch": "1341579657"
            },
            "utcdate": {
                "pretty": "1:00 PM GMT on July 06, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "06",
                "hour": "13",
                "min": "00",
                "tzname": "UTC",
                "epoch": "1341579657"
            },
            "data": {
                "height": "-0.79 ft",
                "type": "Low Tide"
            }
        }, {
            "date": {
                "pretty": "12:00 PM EDT on July 06, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "06",
                "hour": "12",
                "min": "00",
                "tzname": "America/New_York",
                "epoch": "1341590458"
            },
            "utcdate": {
                "pretty": "4:00 PM GMT on July 06, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "06",
                "hour": "16",
                "min": "00",
                "tzname": "UTC",
                "epoch": "1341590458"
            },
            "data": {
                "height": "",
                "type": "Moonset"
            }
        }, {
            "date": {
                "pretty": "3:30 PM EDT on July 06, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "06",
                "hour": "15",
                "min": "30",
                "tzname": "America/New_York",
                "epoch": "1341603035"
            },
            "utcdate": {
                "pretty": "7:30 PM GMT on July 06, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "06",
                "hour": "19",
                "min": "30",
                "tzname": "UTC",
                "epoch": "1341603035"
            },
            "data": {
                "height": "4.49 ft",
                "type": "High Tide"
            }
        }, {
            "date": {
                "pretty": "8:46 PM EDT on July 06, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "06",
                "hour": "20",
                "min": "46",
                "tzname": "America/New_York",
                "epoch": "1341622000"
            },
            "utcdate": {
                "pretty": "12:46 AM GMT on July 07, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "07",
                "hour": "00",
                "min": "46",
                "tzname": "UTC",
                "epoch": "1341622000"
            },
            "data": {
                "height": "1.85 ft",
                "type": "Low Tide"
            }
        }, {
            "date": {
                "pretty": "11:05 PM EDT on July 06, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "06",
                "hour": "23",
                "min": "05",
                "tzname": "America/New_York",
                "epoch": "1341630302"
            },
            "utcdate": {
                "pretty": "3:05 AM GMT on July 07, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "07",
                "hour": "03",
                "min": "05",
                "tzname": "UTC",
                "epoch": "1341630302"
            },
            "data": {
                "height": "",
                "type": "Sunset"
            }
        }, {
            "date": {
                "pretty": "1:09 AM EDT on July 07, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "07",
                "hour": "01",
                "min": "09",
                "tzname": "America/New_York",
                "epoch": "1341637789"
            },
            "utcdate": {
                "pretty": "5:09 AM GMT on July 07, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "07",
                "hour": "05",
                "min": "09",
                "tzname": "UTC",
                "epoch": "1341637789"
            },
            "data": {
                "height": "",
                "type": "Moonrise"
            }
        }, {
            "date": {
                "pretty": "2:46 AM EDT on July 07, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "07",
                "hour": "02",
                "min": "46",
                "tzname": "America/New_York",
                "epoch": "1341643592"
            },
            "utcdate": {
                "pretty": "6:46 AM GMT on July 07, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "07",
                "hour": "06",
                "min": "46",
                "tzname": "UTC",
                "epoch": "1341643592"
            },
            "data": {
                "height": "5.52 ft",
                "type": "High Tide"
            }
        }, {
            "date": {
                "pretty": "8:48 AM EDT on July 07, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "07",
                "hour": "08",
                "min": "48",
                "tzname": "America/New_York",
                "epoch": "1341665286"
            },
            "utcdate": {
                "pretty": "12:48 PM GMT on July 07, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "07",
                "hour": "12",
                "min": "48",
                "tzname": "UTC",
                "epoch": "1341665286"
            },
            "data": {
                "height": "",
                "type": "Sunrise"
            }
        }, {
            "date": {
                "pretty": "9:40 AM EDT on July 07, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "07",
                "hour": "09",
                "min": "40",
                "tzname": "America/New_York",
                "epoch": "1341668402"
            },
            "utcdate": {
                "pretty": "1:40 PM GMT on July 07, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "07",
                "hour": "13",
                "min": "40",
                "tzname": "UTC",
                "epoch": "1341668402"
            },
            "data": {
                "height": "-0.27 ft",
                "type": "Low Tide"
            }
        }, {
            "date": {
                "pretty": "1:02 PM EDT on July 07, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "07",
                "hour": "13",
                "min": "02",
                "tzname": "America/New_York",
                "epoch": "1341680558"
            },
            "utcdate": {
                "pretty": "5:02 PM GMT on July 07, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "07",
                "hour": "17",
                "min": "02",
                "tzname": "UTC",
                "epoch": "1341680558"
            },
            "data": {
                "height": "",
                "type": "Moonset"
            }
        }],
        "tideSummaryStats": [{
            "maxheight": 6.870000,
            "minheight": -1.450000
        }]
    }
}

now_response = {
    "response": {
        "version": "0.1",
        "termsofService": "http://www.wunderground.com/weather/api/d/terms.html",
        "features": {
            "conditions": 1
        }
    }, "current_observation": {
        "image": {
            "url": "http://icons.wxug.com/graphics/wu2/logo_130x80.png",
            "title": "Weather Underground",
            "link": "http://www.wunderground.com"
        },
        "display_location": {
            "full": "Boston, MA",
            "city": "Boston",
            "state": "MA",
            "state_name": "Massachusetts",
            "country": "US",
            "country_iso3166": "US",
            "zip": "02108",
            "magic": "1",
            "wmo": "99999",
            "latitude": "42.36000061",
            "longitude": "-71.06999969",
            "elevation": "21.9"
        },
        "observation_location": {
            "full": "North End, Boston, Boston, Massachusetts",
            "city": "North End, Boston, Boston",
            "state": "Massachusetts",
            "country": "US",
            "country_iso3166": "US",
            "latitude": "42.366951",
            "longitude": "-71.056152",
            "elevation": "69 ft"
        },
        "estimated": {
        },
        "station_id": "KMABOSTO132",
        "observation_time": "Last Updated on November 7, 1:34 PM EST",
        "observation_time_rfc822": "Tue, 07 Nov 2017 13:34:38 -0500",
        "observation_epoch": "1510079678",
        "local_time_rfc822": "Tue, 07 Nov 2017 13:34:47 -0500",
        "local_epoch": "1510079687",
        "local_tz_short": "EST",
        "local_tz_long": "America/New_York",
        "local_tz_offset": "-0500",
        "weather": "Overcast",
        "temperature_string": "47.1 F (8.4 C)",
        "temp_f": 47.1,
        "temp_c": 8.4,
        "relative_humidity": "43%",
        "wind_string": "From the North at 4.3 MPH Gusting to 4.9 MPH",
        "wind_dir": "North",
        "wind_degrees": 352,
        "wind_mph": 4.3,
        "wind_gust_mph": "4.9",
        "wind_kph": 6.9,
        "wind_gust_kph": "7.9",
        "pressure_mb": "1023",
        "pressure_in": "30.21",
        "pressure_trend": "+",
        "dewpoint_string": "26 F (-3 C)",
        "dewpoint_f": 26,
        "dewpoint_c": -3,
        "heat_index_string": "NA",
        "heat_index_f": "NA",
        "heat_index_c": "NA",
        "windchill_string": "45 F (7 C)",
        "windchill_f": "45",
        "windchill_c": "7",
        "feelslike_string": "45 F (7 C)",
        "feelslike_f": "45",
        "feelslike_c": "7",
        "visibility_mi": "10.0",
        "visibility_km": "16.1",
        "solarradiation": "99",
        "UV": "1.0", "precip_1hr_string": "0.00 in ( 0 mm)",
        "precip_1hr_in": "0.00",
        "precip_1hr_metric": " 0",
        "precip_today_string": "0.00 in (0 mm)",
        "precip_today_in": "0.00",
        "precip_today_metric": "0",
        "icon": "cloudy",
        "icon_url": "http://icons.wxug.com/i/c/k/cloudy.gif",
        "forecast_url": "http://www.wunderground.com/US/MA/Boston.html",
        "history_url": "http://www.wunderground.com/weatherstation/WXDailyHistory.asp?ID=KMABOSTO132",
        "ob_url": "http://www.wunderground.com/cgi-bin/findweather/getForecast?query=42.366951,-71.056152",
        "nowcast": ""
    }
}

historical_response = {
    "response": {
        "version": "0.1",
        "termsofService": "http://www.wunderground.com/weather/api/d/terms.html",
        "features": {
            "almanac": 1
        }
    },
    "almanac": {
        "airport_code": "KSFO",
        "temp_high": {
            "normal": {
                "F": "71",
                "C": "22"
            },
            "record": {
                "F": "89",
                "C": "31"
            },
            "recordyear": "1970"
        },
        "temp_low": {
            "normal": {
                "F": "54",
                "C": "12"
            },
            "record": {
                "F": "48",
                "C": "8"
            },
            "recordyear": "1953"
        }
    }
}

date_response = {
    'response': {'features': {'history': 1},
                 'termsofService': 'http://www.wunderground.com/weather/api/d/terms.html',
                 'version': '0.1'}, 'history': {'dailysummary': [{'coolingdegreedays': '0',
                                                                  'coolingdegreedaysnormal': '0',
                                                                  'date': {'hour': '12',
                                                                           'mday': '07',
                                                                           'min': '00',
                                                                           'mon': '11',
                                                                           'pretty': '12:00 PM EST on November '
                                                                           '07, 2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'fog': '0',
                                                                  'gdegreedays': '0',
                                                                  'hail': '0',
                                                                  'heatingdegreedays': '23',
                                                                  'heatingdegreedaysnormal': '18',
                                                                  'humidity': '',
                                                                  'maxdewpti': '36',
                                                                  'maxdewptm': '2',
                                                                  'maxhumidity': '79',
                                                                  'maxpressurei': '30.48',
                                                                  'maxpressurem': '1032',
                                                                  'maxtempi': '47',
                                                                  'maxtempm': '8',
                                                                  'maxvisi': '10',
                                                                  'maxvism': '16',
                                                                  'maxwspdi': '18',
                                                                  'maxwspdm': '29',
                                                                  'meandewpti': '33',
                                                                  'meandewptm': '1',
                                                                  'meanpressurei': '30.40',
                                                                  'meanpressurem': '1029',
                                                                  'meantempi': '42',
                                                                  'meantempm': '6',
                                                                  'meanvisi': '10',
                                                                  'meanvism': '16',
                                                                  'meanwdird': '4',
                                                                  'meanwdire': '',
                                                                  'meanwindspdi': '9',
                                                                  'meanwindspdm': '15',
                                                                  'mindewpti': '27',
                                                                  'mindewptm': '-3',
                                                                  'minhumidity': '59',
                                                                  'minpressurei': '30.26',
                                                                  'minpressurem': '1025',
                                                                  'mintempi': '36',
                                                                  'mintempm': '2',
                                                                  'minvisi': '10',
                                                                  'minvism': '16',
                                                                  'minwspdi': '4',
                                                                  'minwspdm': '6',
                                                                  'monthtodatecoolingdegreedays': '0',
                                                                  'monthtodatecoolingdegreedaysnormal': '0',
                                                                  'monthtodateheatingdegreedays': '112',
                                                                  'monthtodateheatingdegreedaysnormal': '118',
                                                                  'monthtodatesnowfalli': 'T',
                                                                  'monthtodatesnowfallm': 'T',
                                                                  'precipi': '0.00',
                                                                  'precipm': '0.00',
                                                                  'precipsource': '',
                                                                  'rain': '0',
                                                                  'since1jancoolingdegreedays': '1035',
                                                                  'since1jancoolingdegreedaysnormal': '747',
                                                                  'since1julheatingdegreedays': '470',
                                                                  'since1julheatingdegreedaysnormal': '565',
                                                                  'since1julsnowfalli': 'T',
                                                                  'since1julsnowfallm': 'T',
                                                                  'since1sepcoolingdegreedays': '141',
                                                                  'since1sepcoolingdegreedaysnormal': '88',
                                                                  'since1sepheatingdegreedays': '463',
                                                                  'since1sepheatingdegreedaysnormal': '552',
                                                                  'snow': '0',
                                                                  'snowdepthi': '0.00',
                                                                  'snowdepthm': '0.00',
                                                                  'snowfalli': '0.00',
                                                                  'snowfallm': '0.00',
                                                                  'thunder': '0',
                                                                  'tornado': '0'}],
                                                'date': {'hour': '12',
                                                         'mday': '07',
                                                         'min': '00',
                                                         'mon': '11',
                                                         'pretty': 'November 7, 2016',
                                                         'tzname': 'America/New_York',
                                                         'year': '2016'},
                                                'observations': [{'conds': 'Mostly Cloudy',
                                                                  'date': {'hour': '00',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '12:54 AM EST on November '
                                                                           '07, 2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '30.0',
                                                                  'dewptm': '-1.1',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '62',
                                                                  'icon': 'mostlycloudy',
                                                                  'metar': 'METAR KBOS 070554Z 35011KT 10SM '
                                                                  'BKN070 06/M01 A3038 RMK AO2 SLP285 '
                                                                  'T00561011 10083 20056 53006',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.38',
                                                                  'pressurem': '1028.5',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '42.1',
                                                                  'tempm': '5.6',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '05',
                                                                              'mday': '07',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '5:54 AM GMT on November '
                                                                              '07, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '350',
                                                                  'wdire': 'North',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '35.2',
                                                                  'windchillm': '1.8',
                                                                  'wspdi': '12.7',

                                                                  'wspdm': '20.4'},
                                                                 {'conds': 'Partly Cloudy',
                                                                  'date': {'hour': '01',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '1:54 AM EST on November 07, '
                                                                           '2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '27.0',
                                                                  'dewptm': '-2.8',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '60',
                                                                  'icon': 'partlycloudy',
                                                                  'metar': 'METAR KBOS 070654Z 36012KT 10SM '
                                                                  'FEW060 04/M03 A3039 RMK AO2 SLP291 '
                                                                  'T00441028',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.39',
                                                                  'pressurem': '1029.1',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '39.9',
                                                                  'tempm': '4.4',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '06',
                                                                              'mday': '07',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '6:54 AM GMT on November '
                                                                              '07, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '360',
                                                                  'wdire': 'North',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '32.1',
                                                                  'windchillm': '0.1',
                                                                  'wspdi': '13.8',
                                                                  'wspdm': '22.2'},
                                                                 {'conds': 'Partly Cloudy',
                                                                  'date': {'hour': '02',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '2:54 AM EST on November 07, '
                                                                           '2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '28.0',
                                                                  'dewptm': '-2.2',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '65',
                                                                  'icon': 'partlycloudy',
                                                                  'metar': 'METAR KBOS 070754Z 35008KT 10SM '
                                                                  'FEW060 04/M02 A3040 RMK AO2 SLP293 '
                                                                  'T00391022',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.40',
                                                                  'pressurem': '1029.3',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '39.0',
                                                                  'tempm': '3.9',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '07',
                                                                              'mday': '07',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '7:54 AM GMT on November '
                                                                              '07, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '350',
                                                                  'wdire': 'North',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '32.8',
                                                                  'windchillm': '0.4',
                                                                  'wspdi': '9.2',
                                                                  'wspdm': '14.8'},
                                                                 {'conds': 'Partly Cloudy',
                                                                  'date': {'hour': '03',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '3:54 AM EST on November 07, '
                                                                           '2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '28.9',
                                                                  'dewptm': '-1.7',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '70',
                                                                  'icon': 'partlycloudy',
                                                                  'metar': 'METAR KBOS 070854Z 36011KT 10SM '
                                                                  'FEW060 03/M02 A3042 RMK AO2 SLP299 '
                                                                  'T00331017 52014',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.42',
                                                                  'pressurem': '1029.9',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '37.9',
                                                                  'tempm': '3.3',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '08',
                                                                              'mday': '07',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '8:54 AM GMT on November '
                                                                              '07, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '360',
                                                                  'wdire': 'North',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '30.0',
                                                                  'windchillm': '-1.1',
                                                                  'wspdi': '12.7',
                                                                  'wspdm': '20.4'},
                                                                 {'conds': 'Partly Cloudy',
                                                                  'date': {'hour': '04',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '4:54 AM EST on November 07, '
                                                                           '2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '28.9',
                                                                  'dewptm': '-1.7',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '73',
                                                                  'icon': 'partlycloudy',
                                                                  'metar': 'METAR KBOS 070954Z 35010KT 10SM '
                                                                  'FEW060 03/M02 A3043 RMK AO2 SLP304 '
                                                                  'T00281017',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.43',
                                                                  'pressurem': '1030.4',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '37.0',
                                                                  'tempm': '2.8',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '09',
                                                                              'mday': '07',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '9:54 AM GMT on November '
                                                                              '07, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '350',
                                                                  'wdire': 'North',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '29.3',
                                                                  'windchillm': '-1.5',
                                                                  'wspdi': '11.5',
                                                                  'wspdm': '18.5'},
                                                                 {'conds': 'Partly Cloudy',
                                                                  'date': {'hour': '05',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '5:54 AM EST on November 07, '
                                                                           '2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '28.0',
                                                                  'dewptm': '-2.2',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '70',
                                                                  'icon': 'partlycloudy',
                                                                  'metar': 'METAR KBOS 071054Z 35011KT 10SM '
                                                                  'FEW060 03/M02 A3045 RMK AO2 SLP309 '
                                                                  'T00281022',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.45',
                                                                  'pressurem': '1030.9',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '37.0',
                                                                  'tempm': '2.8',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '10',
                                                                              'mday': '07',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '10:54 AM GMT on November '
                                                                              '07, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '350',
                                                                  'wdire': 'North',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '28.9',
                                                                  'windchillm': '-1.7',
                                                                  'wspdi': '12.7',
                                                                  'wspdm': '20.4'},
                                                                 {'conds': 'Partly Cloudy',
                                                                  'date': {'hour': '06',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '6:54 AM EST on November 07, '
                                                                           '2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '28.9',
                                                                  'dewptm': '-1.7',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '76',
                                                                  'icon': 'partlycloudy',
                                                                  'metar': 'METAR KBOS 071154Z 35010KT 10SM '
                                                                  'FEW050 FEW250 02/M02 A3046 RMK AO2 '
                                                                  'SLP313 70006 T00221017 10056 20022 '
                                                                  '52014',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.46',
                                                                  'pressurem': '1031.3',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '36.0',
                                                                  'tempm': '2.2',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '11',
                                                                              'mday': '07',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '11:54 AM GMT on November '
                                                                              '07, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '350',
                                                                  'wdire': 'North',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '28.0',
                                                                  'windchillm': '-2.2',
                                                                  'wspdi': '11.5',
                                                                  'wspdm': '18.5'},
                                                                 {'conds': 'Scattered Clouds',
                                                                  'date': {'hour': '07',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '7:54 AM EST on November 07, '
                                                                           '2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '30.0',
                                                                  'dewptm': '-1.1',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '76',
                                                                  'icon': 'partlycloudy',
                                                                  'metar': 'METAR KBOS 071254Z 36009KT 10SM '
                                                                  'SCT032 SCT250 03/M01 A3047 RMK AO2 '
                                                                  'SLP318 T00281011',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.47',
                                                                  'pressurem': '1031.8',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '37.0',
                                                                  'tempm': '2.8',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '12',
                                                                              'mday': '07',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '12:54 PM GMT on November '
                                                                              '07, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '360',
                                                                  'wdire': 'North',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '29.8',
                                                                  'windchillm': '-1.2',
                                                                  'wspdi': '10.4',
                                                                  'wspdm': '16.7'},
                                                                 {'conds': 'Mostly Cloudy',
                                                                  'date': {'hour': '08',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '8:54 AM EST on November 07, '
                                                                           '2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '32.0',
                                                                  'dewptm': '0.0',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '70',
                                                                  'icon': 'mostlycloudy',
                                                                  'metar': 'METAR KBOS 071354Z 35010KT 10SM '
                                                                  'BKN032 05/00 A3048 RMK AO2 SLP321 '
                                                                  'T00500000',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.48',
                                                                  'pressurem': '1032.1',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '41.0',
                                                                  'tempm': '5.0',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '13',
                                                                              'mday': '07',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '1:54 PM GMT on November '
                                                                              '07, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '350',
                                                                  'wdire': 'North',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '34.3',
                                                                  'windchillm': '1.3',
                                                                  'wspdi': '11.5',
                                                                  'wspdm': '18.5'},
                                                                 {'conds': 'Mostly Cloudy',
                                                                  'date': {'hour': '09',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '9:54 AM EST on November 07, '
                                                                           '2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '33.1',
                                                                  'dewptm': '0.6',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '68',
                                                                  'icon': 'mostlycloudy',
                                                                  'metar': 'METAR KBOS 071454Z 36012KT 10SM '
                                                                  'BKN033 06/01 A3048 RMK AO2 SLP322 '
                                                                  'T00610006 51008',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.48',
                                                                  'pressurem': '1032.2',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '43.0',
                                                                  'tempm': '6.1',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '14',
                                                                              'mday': '07',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '2:54 PM GMT on November '
                                                                              '07, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '360',
                                                                  'wdire': 'North',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '36.0',
                                                                  'windchillm': '2.2',
                                                                  'wspdi': '13.8',
                                                                  'wspdm': '22.2'},
                                                                 {'conds': 'Partly Cloudy',
                                                                  'date': {'hour': '10',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '10:54 AM EST on November '
                                                                           '07, 2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '35.1',
                                                                  'dewptm': '1.7',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '66',
                                                                  'icon': 'partlycloudy',
                                                                  'metar': 'METAR KBOS 071554Z 02012KT 10SM '
                                                                  'FEW033 08/02 A3047 RMK AO2 SLP315 '
                                                                  'T00780017',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.46',
                                                                  'pressurem': '1031.5',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '46.0',
                                                                  'tempm': '7.8',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '15',
                                                                              'mday': '07',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '3:54 PM GMT on November '
                                                                              '07, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '20',
                                                                  'wdire': 'NNE',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '39.9',
                                                                  'windchillm': '4.4',
                                                                  'wspdi': '13.8',
                                                                  'wspdm': '22.2'},
                                                                 {'conds': 'Mostly Cloudy',
                                                                  'date': {'hour': '11',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '11:54 AM EST on November '
                                                                           '07, 2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '34.0',
                                                                  'dewptm': '1.1',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '65',
                                                                  'icon': 'mostlycloudy',
                                                                  'metar': 'METAR KBOS 071654Z 01012G17KT 10SM '
                                                                  'BKN028 07/01 A3045 RMK AO2 SLP311 '
                                                                  'T00720011',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.45',
                                                                  'pressurem': '1031.1',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '45.0',
                                                                  'tempm': '7.2',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '16',
                                                                              'mday': '07',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '4:54 PM GMT on November '
                                                                              '07, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '10',
                                                                  'wdire': 'North',
                                                                  'wgusti': '19.6',
                                                                  'wgustm': '31.5',
                                                                  'windchilli': '38.5',
                                                                  'windchillm': '3.6',
                                                                  'wspdi': '13.8',
                                                                  'wspdm': '22.2'},
                                                                 {'conds': 'Mostly Cloudy',
                                                                  'date': {'hour': '12',
                                                                           'mday': '07',
                                                                           'min': '22',
                                                                           'mon': '11',
                                                                           'pretty': '12:22 PM EST on November '
                                                                           '07, 2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '34.0',
                                                                  'dewptm': '1.1',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '63',
                                                                  'icon': 'mostlycloudy',
                                                                  'metar': 'SPECI KBOS 071722Z 02013KT 10SM '
                                                                  'BKN030 08/01 A3044 RMK AO2 T00780011',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.44',
                                                                  'pressurem': '1030.7',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '46.0',
                                                                  'tempm': '7.8',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '17',
                                                                              'mday': '07',
                                                                              'min': '22',
                                                                              'mon': '11',
                                                                              'pretty': '5:22 PM GMT on November '
                                                                              '07, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '20',
                                                                  'wdire': 'NNE',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '39.6',
                                                                  'windchillm': '4.2',
                                                                  'wspdi': '15.0',
                                                                  'wspdm': '24.1'},
                                                                 {'conds': 'Partly Cloudy',
                                                                  'date': {'hour': '12',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '12:54 PM EST on November '
                                                                           '07, 2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '34.0',
                                                                  'dewptm': '1.1',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '63',
                                                                  'icon': 'partlycloudy',
                                                                  'metar': 'METAR KBOS 071754Z 03009KT 10SM '
                                                                  'FEW032 FEW250 08/01 A3043 RMK AO2 '
                                                                  'SLP303 T00780011 10083 20022 58019',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.43',
                                                                  'pressurem': '1030.3',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '46.0',
                                                                  'tempm': '7.8',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '17',
                                                                              'mday': '07',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '5:54 PM GMT on November '
                                                                              '07, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '30',
                                                                  'wdire': 'NNE',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '41.0',
                                                                  'windchillm': '5.0',
                                                                  'wspdi': '10.4',
                                                                  'wspdm': '16.7'},
                                                                 {'conds': 'Partly Cloudy',
                                                                  'date': {'hour': '13',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '1:54 PM EST on November 07, '
                                                                           '2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '35.1',
                                                                  'dewptm': '1.7',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '66',
                                                                  'icon': 'partlycloudy',
                                                                  'metar': 'METAR KBOS 071854Z 07008KT 10SM '
                                                                  'FEW035 FEW250 08/02 A3041 RMK AO2 '
                                                                  'SLP295 T00780017',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.40',
                                                                  'pressurem': '1029.5',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '46.0',
                                                                  'tempm': '7.8',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '18',
                                                                              'mday': '07',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '6:54 PM GMT on November '
                                                                              '07, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '70',
                                                                  'wdire': 'ENE',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '41.4',
                                                                  'windchillm': '5.2',
                                                                  'wspdi': '9.2',
                                                                  'wspdm': '14.8'},
                                                                 {'conds': 'Partly Cloudy',
                                                                  'date': {'hour': '14',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '2:54 PM EST on November 07, '
                                                                           '2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '35.1',
                                                                  'dewptm': '1.7',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '66',
                                                                  'icon': 'partlycloudy',
                                                                  'metar': 'METAR KBOS 071954Z 10007KT 10SM '
                                                                  'FEW035 FEW250 08/02 A3039 RMK AO2 '
                                                                  'SLP290 T00780017',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.39',
                                                                  'pressurem': '1029.0',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '46.0',
                                                                  'tempm': '7.8',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '19',
                                                                              'mday': '07',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '7:54 PM GMT on November '
                                                                              '07, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '100',
                                                                  'wdire': 'East',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '41.9',
                                                                  'windchillm': '5.5',
                                                                  'wspdi': '8.1',
                                                                  'wspdm': '13.0'},
                                                                 {'conds': 'Partly Cloudy',
                                                                  'date': {'hour': '15',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '3:54 PM EST on November 07, '
                                                                           '2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '35.1',
                                                                  'dewptm': '1.7',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '71',
                                                                  'icon': 'partlycloudy',
                                                                  'metar': 'METAR KBOS 072054Z 11004KT 10SM '
                                                                  'FEW035 FEW250 07/02 A3038 RMK AO2 '
                                                                  'SLP285 T00670017 56018',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.38',
                                                                  'pressurem': '1028.5',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '44.1',
                                                                  'tempm': '6.7',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '20',
                                                                              'mday': '07',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '8:54 PM GMT on November '
                                                                              '07, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '110',
                                                                  'wdire': 'ESE',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '41.5',
                                                                  'windchillm': '5.3',
                                                                  'wspdi': '4.6',
                                                                  'wspdm': '7.4'},
                                                                 {'conds': 'Partly Cloudy',
                                                                  'date': {'hour': '16',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '4:54 PM EST on November 07, '
                                                                           '2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '34.0',
                                                                  'dewptm': '1.1',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '71',
                                                                  'icon': 'partlycloudy',
                                                                  'metar': 'METAR KBOS 072154Z 10003KT 10SM '
                                                                  'FEW035 06/01 A3037 RMK AO2 SLP282 '
                                                                  'T00610011',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.37',
                                                                  'pressurem': '1028.2',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '43.0',
                                                                  'tempm': '6.1',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '21',
                                                                              'mday': '07',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '9:54 PM GMT on November '
                                                                              '07, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '100',
                                                                  'wdire': 'East',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '41.3',
                                                                  'windchillm': '5.2',
                                                                  'wspdi': '3.5',
                                                                  'wspdm': '5.6'},
                                                                 {'conds': 'Partly Cloudy',
                                                                  'date': {'hour': '17',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '5:54 PM EST on November 07, '
                                                                           '2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '35.1',
                                                                  'dewptm': '1.7',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '74',
                                                                  'icon': 'partlycloudy',
                                                                  'metar': 'METAR KBOS 072254Z 16004KT 10SM '
                                                                  'FEW035 06/02 A3036 RMK AO2 SLP279 '
                                                                  'T00610017',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.36',
                                                                  'pressurem': '1027.9',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '43.0',
                                                                  'tempm': '6.1',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '22',
                                                                              'mday': '07',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '10:54 PM GMT on November '
                                                                              '07, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '160',
                                                                  'wdire': 'SSE',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '40.3',
                                                                  'windchillm': '4.6',
                                                                  'wspdi': '4.6',
                                                                  'wspdm': '7.4'},
                                                                 {'conds': 'Clear',
                                                                  'date': {'hour': '18',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '6:54 PM EST on November 07, '
                                                                           '2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '36.0',
                                                                  'dewptm': '2.2',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '76',
                                                                  'icon': 'clear',
                                                                  'metar': 'METAR KBOS 072354Z 17005KT 10SM CLR '
                                                                  '06/02 A3035 RMK AO2 SLP278 T00610022 '
                                                                  '10083 20061 56007',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.35',
                                                                  'pressurem': '1027.8',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '43.0',
                                                                  'tempm': '6.1',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '23',
                                                                              'mday': '07',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '11:54 PM GMT on November '
                                                                              '07, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '170',
                                                                  'wdire': 'South',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '39.5',
                                                                  'windchillm': '4.2',
                                                                  'wspdi': '5.8',
                                                                  'wspdm': '9.3'},
                                                                 {'conds': 'Clear',
                                                                  'date': {'hour': '19',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '7:54 PM EST on November 07, '
                                                                           '2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '36.0',
                                                                  'dewptm': '2.2',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '79',
                                                                  'icon': 'clear',
                                                                  'metar': 'METAR KBOS 080054Z 20004KT 10SM CLR '
                                                                  '06/02 A3035 RMK AO2 SLP275 T00560022',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.35',
                                                                  'pressurem': '1027.5',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '42.1',
                                                                  'tempm': '5.6',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '00',
                                                                              'mday': '08',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '12:54 AM GMT on November '
                                                                              '08, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '200',
                                                                  'wdire': 'SSW',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '39.2',
                                                                  'windchillm': '4.0',
                                                                  'wspdi': '4.6',
                                                                  'wspdm': '7.4'},
                                                                 {'conds': 'Clear',
                                                                  'date': {'hour': '20',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '8:54 PM EST on November 07, '
                                                                           '2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '35.1',
                                                                  'dewptm': '1.7',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '79',
                                                                  'icon': 'clear',
                                                                  'metar': 'METAR KBOS 080154Z 24005KT 10SM CLR '
                                                                  '05/02 A3034 RMK AO2 SLP272 T00500017',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.34',
                                                                  'pressurem': '1027.2',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '41.0',
                                                                  'tempm': '5.0',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '01',
                                                                              'mday': '08',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '1:54 AM GMT on November '
                                                                              '08, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '240',
                                                                  'wdire': 'WSW',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '37.1',
                                                                  'windchillm': '2.8',
                                                                  'wspdi': '5.8',
                                                                  'wspdm': '9.3'},
                                                                 {'conds': 'Clear',
                                                                  'date': {'hour': '21',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '9:54 PM EST on November 07, '
                                                                           '2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '35.1',
                                                                  'dewptm': '1.7',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '79',
                                                                  'icon': 'clear',
                                                                  'metar': 'METAR KBOS 080254Z 24005KT 10SM CLR '
                                                                  '05/02 A3031 RMK AO2 SLP262 T00500017 '
                                                                  '58015',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.31',
                                                                  'pressurem': '1026.2',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '41.0',
                                                                  'tempm': '5.0',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '02',
                                                                              'mday': '08',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '2:54 AM GMT on November '
                                                                              '08, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '240',
                                                                  'wdire': 'WSW',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '37.1',
                                                                  'windchillm': '2.8',
                                                                  'wspdi': '5.8',
                                                                  'wspdm': '9.3'},
                                                                 {'conds': 'Clear',
                                                                  'date': {'hour': '22',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '10:54 PM EST on November '
                                                                           '07, 2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '35.1',
                                                                  'dewptm': '1.7',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '76',
                                                                  'icon': 'clear',
                                                                  'metar': 'METAR KBOS 080354Z 27004KT 10SM CLR '
                                                                  '06/02 A3029 RMK AO2 SLP255 T00560017',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.29',
                                                                  'pressurem': '1025.5',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '42.1',
                                                                  'tempm': '5.6',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '03',
                                                                              'mday': '08',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '3:54 AM GMT on November '
                                                                              '08, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '270',
                                                                  'wdire': 'West',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '39.2',
                                                                  'windchillm': '4.0',
                                                                  'wspdi': '4.6',
                                                                  'wspdm': '7.4'},
                                                                 {'conds': 'Clear',
                                                                  'date': {'hour': '23',
                                                                           'mday': '07',
                                                                           'min': '54',
                                                                           'mon': '11',
                                                                           'pretty': '11:54 PM EST on November '
                                                                           '07, 2016',
                                                                           'tzname': 'America/New_York',
                                                                           'year': '2016'},
                                                                  'dewpti': '34.0',
                                                                  'dewptm': '1.1',
                                                                  'fog': '0',
                                                                  'hail': '0',
                                                                  'heatindexi': '-9999',
                                                                  'heatindexm': '-9999',
                                                                  'hum': '79',
                                                                  'icon': 'clear',
                                                                  'metar': 'METAR KBOS 080454Z 28005KT 10SM CLR '
                                                                  '04/01 A3026 RMK AO2 SLP247 T00440011 '
                                                                  '400830022',
                                                                  'precipi': '-9999.00',
                                                                  'precipm': '-9999.00',
                                                                  'pressurei': '30.26',
                                                                  'pressurem': '1024.7',
                                                                  'rain': '0',
                                                                  'snow': '0',
                                                                  'tempi': '39.9',
                                                                  'tempm': '4.4',
                                                                  'thunder': '0',
                                                                  'tornado': '0',
                                                                  'utcdate': {'hour': '04',
                                                                              'mday': '08',
                                                                              'min': '54',
                                                                              'mon': '11',
                                                                              'pretty': '4:54 AM GMT on November '
                                                                              '08, 2016',
                                                                              'tzname': 'UTC',
                                                                              'year': '2016'},
                                                                  'visi': '10.0',
                                                                  'vism': '16.1',
                                                                  'wdird': '280',
                                                                  'wdire': 'West',
                                                                  'wgusti': '-9999.0',
                                                                  'wgustm': '-9999.0',
                                                                  'windchilli': '35.8',
                                                                  'windchillm': '2.1',
                                                                  'wspdi': '5.8',
                                                                  'wspdm': '9.3'}],
                                                'utcdate': {'hour': '17',
                                                            'mday': '07',
                                                            'min': '00',
                                                            'mon': '11',
                                                            'pretty': 'November 7, 2016',
                                                            'tzname': 'UTC',
                                                            'year': '2016'}}
}

yesterday_response = {
    "response": {
        "version": "0.1",
        "termsofService": "http://www.wunderground.com/weather/api/d/terms.html",
        "features": {
            "yesterday": 1
        }
    },
    "history": {
        "date": {
            "pretty": "July 2, 2012",
            "year": "2012",
            "mon": "07",
            "mday": "02",
            "hour": "12",
            "min": "00",
            "tzname": "America/Los_Angeles"
        },
        "utcdate": {
            "pretty": "July 2, 2012",
            "year": "2012",
            "mon": "07",
            "mday": "02",
            "hour": "19",
            "min": "00",
            "tzname": "UTC"
        },
        "observations": [{
            "date": {
                "pretty": "12:56 AM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "00",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "7:56 AM GMT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "07",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "15.0",
            "tempi": "59.0",
            "dewptm": "11.7",
            "dewpti": "53.1",
            "hum": "81",
            "wspdm": "9.3",
            "wspdi": "5.8",
            "wgustm": "-9999.0",
            "wgusti": "-9999.0",
            "wdird": "240",
            "wdire": "WSW",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1012.3",
            "pressurei": "29.90",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Overcast",
            "icon": "cloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 020756Z 24005KT 10SM SCT007 BKN011 OVC014 15/12 A2989 RMK AO2 SLP123 T01500117 402000144 $"
        }, {
            "date": {
                "pretty": "1:56 AM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "01",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "8:56 AM GMT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "08",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "15.0",
            "tempi": "59.0",
            "dewptm": "11.7",
            "dewpti": "53.1",
            "hum": "81",
            "wspdm": "9.3",
            "wspdi": "5.8",
            "wgustm": "-9999.0",
            "wgusti": "-9999.0",
            "wdird": "220",
            "wdire": "SW",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1012.0",
            "pressurei": "29.89",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Mostly Cloudy",
            "icon": "mostlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 020856Z 22005KT 10SM SCT007 BKN011 BKN019 15/12 A2989 RMK AO2 SLP120 T01500117 58008 $"
        }, {
            "date": {
                "pretty": "2:56 AM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "02",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "9:56 AM GMT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "09",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "15.0",
            "tempi": "59.0",
            "dewptm": "11.1",
            "dewpti": "52.0",
            "hum": "78",
            "wspdm": "13.0",
            "wspdi": "8.1",
            "wgustm": "-9999.0",
            "wgusti": "-9999.0",
            "wdird": "230",
            "wdire": "SW",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1011.7",
            "pressurei": "29.88",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Mostly Cloudy",
            "icon": "mostlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 020956Z 23007KT 10SM SCT007 BKN011 BKN019 15/11 A2988 RMK AO2 SLP117 T01500111 $"
        }, {
            "date": {
                "pretty": "3:56 AM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "03",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "10:56 AM GMT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "10",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "14.4",
            "tempi": "57.9",
            "dewptm": "11.1",
            "dewpti": "52.0",
            "hum": "81",
            "wspdm": "7.4",
            "wspdi": "4.6",
            "wgustm": "-9999.0",
            "wgusti": "-9999.0",
            "wdird": "300",
            "wdire": "WNW",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1011.4",
            "pressurei": "29.87",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Mostly Cloudy",
            "icon": "mostlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 021056Z 30004KT 10SM SCT007 BKN011 BKN019 14/11 A2987 RMK AO2 SLP114 T01440111 $"
        }, {
            "date": {
                "pretty": "4:03 AM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "04",
                "min": "03",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "11:03 AM GMT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "11",
                "min": "03",
                "tzname": "UTC"
            },
            "tempm": "14.0",
            "tempi": "57.2",
            "dewptm": "11.0",
            "dewpti": "51.8",
            "hum": "82",
            "wspdm": "7.4",
            "wspdi": "4.6",
            "wgustm": "-9999.0",
            "wgusti": "-9999.0",
            "wdird": "290",
            "wdire": "WNW",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1011.4",
            "pressurei": "29.87",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Partly Cloudy",
            "icon": "partlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "SPECI KSFO 021103Z 29004KT 10SM FEW011 14/11 A2987 RMK AO2 $"
        }, {
            "date": {
                "pretty": "4:56 AM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "04",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "11:56 AM GMT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "11",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "13.9",
            "tempi": "57.0",
            "dewptm": "11.1",
            "dewpti": "52.0",
            "hum": "83",
            "wspdm": "13.0",
            "wspdi": "8.1",
            "wgustm": "-9999.0",
            "wgusti": "-9999.0",
            "wdird": "270",
            "wdire": "West",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1011.8",
            "pressurei": "29.88",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Mostly Cloudy",
            "icon": "mostlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 021156Z 27007KT 10SM FEW007 BKN013 14/11 A2988 RMK AO2 SLP118 T01390111 10156 20139 55002 $"
        }, {
            "date": {
                "pretty": "5:56 AM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "05",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "12:56 PM GMT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "12",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "13.9",
            "tempi": "57.0",
            "dewptm": "10.6",
            "dewpti": "51.1",
            "hum": "81",
            "wspdm": "9.3",
            "wspdi": "5.8",
            "wgustm": "-9999.0",
            "wgusti": "-9999.0",
            "wdird": "230",
            "wdire": "SW",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1012.3",
            "pressurei": "29.90",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Mostly Cloudy",
            "icon": "mostlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 021256Z 23005KT 10SM FEW007 BKN013 BKN015 14/11 A2990 RMK AO2 SLP123 T01390106 $"
        }, {
            "date": {
                "pretty": "6:56 AM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "06",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "1:56 PM GMT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "13",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "14.4",
            "tempi": "57.9",
            "dewptm": "10.6",
            "dewpti": "51.1",
            "hum": "78",
            "wspdm": "13.0",
            "wspdi": "8.1",
            "wgustm": "-9999.0",
            "wgusti": "-9999.0",
            "wdird": "230",
            "wdire": "SW",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1012.6",
            "pressurei": "29.91",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Mostly Cloudy",
            "icon": "mostlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 021356Z 23007KT 10SM FEW007 BKN013 14/11 A2990 RMK AO2 SLP126 T01440106 $"
        }, {
            "date": {
                "pretty": "7:56 AM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "07",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "2:56 PM GMT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "14",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "14.4",
            "tempi": "57.9",
            "dewptm": "10.6",
            "dewpti": "51.1",
            "hum": "78",
            "wspdm": "-9999.0",
            "wspdi": "-9999.0",
            "wgustm": "-9999.0",
            "wgusti": "-9999.0",
            "wdird": "0",
            "wdire": "North",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1012.9",
            "pressurei": "29.91",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Mostly Cloudy",
            "icon": "mostlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 021456Z 10SM FEW006 BKN011 BKN014 14/11 A2991 RMK AO2 SLP129 T01440106 51010 $"
        }, {
            "date": {
                "pretty": "8:56 AM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "08",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "3:56 PM GMT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "15",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "15.6",
            "tempi": "60.1",
            "dewptm": "11.1",
            "dewpti": "52.0",
            "hum": "75",
            "wspdm": "20.4",
            "wspdi": "12.7",
            "wgustm": "-9999.0",
            "wgusti": "-9999.0",
            "wdird": "270",
            "wdire": "West",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1013.1",
            "pressurei": "29.92",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Mostly Cloudy",
            "icon": "mostlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 021556Z 27011KT 10SM FEW006 BKN011 BKN014 16/11 A2992 RMK AO2 SLP131 T01560111 $"
        }, {
            "date": {
                "pretty": "9:08 AM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "09",
                "min": "08",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "4:08 PM GMT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "16",
                "min": "08",
                "tzname": "UTC"
            },
            "tempm": "16.0",
            "tempi": "60.8",
            "dewptm": "11.0",
            "dewpti": "51.8",
            "hum": "72",
            "wspdm": "22.2",
            "wspdi": "13.8",
            "wgustm": "-9999.0",
            "wgusti": "-9999.0",
            "wdird": "270",
            "wdire": "West",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1013.1",
            "pressurei": "29.92",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Scattered Clouds",
            "icon": "partlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "SPECI KSFO 021608Z 27012KT 10SM FEW007 SCT016 16/11 A2992 RMK AO2 $"
        }, {
            "date": {
                "pretty": "9:56 AM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "09",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "4:56 PM GMT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "16",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "16.1",
            "tempi": "61.0",
            "dewptm": "10.6",
            "dewpti": "51.1",
            "hum": "70",
            "wspdm": "27.8",
            "wspdi": "17.3",
            "wgustm": "-9999.0",
            "wgusti": "-9999.0",
            "wdird": "270",
            "wdire": "West",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1013.3",
            "pressurei": "29.93",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Scattered Clouds",
            "icon": "partlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 021656Z 27015KT 10SM FEW006 SCT014 16/11 A2993 RMK AO2 SLP133 T01610106"
        }, {
            "date": {
                "pretty": "10:56 AM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "10",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "5:56 PM GMT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "17",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "16.7",
            "tempi": "62.1",
            "dewptm": "10.6",
            "dewpti": "51.1",
            "hum": "67",
            "wspdm": "24.1",
            "wspdi": "15.0",
            "wgustm": "35.2",
            "wgusti": "21.9",
            "wdird": "270",
            "wdire": "West",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1013.3",
            "pressurei": "29.93",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Partly Cloudy",
            "icon": "partlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 021756Z 27013G19KT 10SM FEW007 17/11 A2993 RMK AO2 SLP133 T01670106 10172 20139 51004"
        }, {
            "date": {
                "pretty": "11:56 AM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "11",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "6:56 PM GMT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "18",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "17.8",
            "tempi": "64.0",
            "dewptm": "10.6",
            "dewpti": "51.1",
            "hum": "63",
            "wspdm": "25.9",
            "wspdi": "16.1",
            "wgustm": "-9999.0",
            "wgusti": "-9999.0",
            "wdird": "260",
            "wdire": "West",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1013.2",
            "pressurei": "29.92",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Partly Cloudy",
            "icon": "partlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 021856Z 26014KT 10SM FEW008 18/11 A2992 RMK AO2 SLP132 T01780106"
        }, {
            "date": {
                "pretty": "12:56 PM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "12",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "7:56 PM GMT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "19",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "18.3",
            "tempi": "64.9",
            "dewptm": "10.6",
            "dewpti": "51.1",
            "hum": "61",
            "wspdm": "25.9",
            "wspdi": "16.1",
            "wgustm": "37.0",
            "wgusti": "23.0",
            "wdird": "260",
            "wdire": "West",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1013.2",
            "pressurei": "29.92",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Partly Cloudy",
            "icon": "partlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 021956Z 26014G20KT 10SM FEW008 18/11 A2992 RMK AO2 SLP132 T01830106"
        }, {
            "date": {
                "pretty": "1:56 PM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "13",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "8:56 PM GMT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "20",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "18.3",
            "tempi": "64.9",
            "dewptm": "10.6",
            "dewpti": "51.1",
            "hum": "61",
            "wspdm": "31.5",
            "wspdi": "19.6",
            "wgustm": "-9999.0",
            "wgusti": "-9999.0",
            "wdird": "270",
            "wdire": "West",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1013.3",
            "pressurei": "29.93",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Partly Cloudy",
            "icon": "partlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 022056Z 27017KT 10SM FEW010 18/11 A2992 RMK AO2 SLP133 T01830106 55001"
        }, {
            "date": {
                "pretty": "2:56 PM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "14",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "9:56 PM GMT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "21",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "17.8",
            "tempi": "64.0",
            "dewptm": "10.6",
            "dewpti": "51.1",
            "hum": "63",
            "wspdm": "29.6",
            "wspdi": "18.4",
            "wgustm": "42.6",
            "wgusti": "26.5",
            "wdird": "250",
            "wdire": "WSW",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1013.2",
            "pressurei": "29.92",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Scattered Clouds",
            "icon": "partlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 022156Z 25016G23KT 10SM SCT010 18/11 A2992 RMK AO2 SLP132 T01780106"
        }, {
            "date": {
                "pretty": "3:56 PM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "15",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "10:56 PM GMT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "22",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "18.3",
            "tempi": "64.9",
            "dewptm": "10.0",
            "dewpti": "50.0",
            "hum": "58",
            "wspdm": "27.8",
            "wspdi": "17.3",
            "wgustm": "42.6",
            "wgusti": "26.5",
            "wdird": "270",
            "wdire": "West",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1012.9",
            "pressurei": "29.91",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Partly Cloudy",
            "icon": "partlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 022256Z 27015G23KT 10SM FEW010 18/10 A2991 RMK AO2 PK WND 27028/2239 SLP129 T01830100"
        }, {
            "date": {
                "pretty": "4:56 PM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "16",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "11:56 PM GMT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "23",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "17.8",
            "tempi": "64.0",
            "dewptm": "10.0",
            "dewpti": "50.0",
            "hum": "60",
            "wspdm": "35.2",
            "wspdi": "21.9",
            "wgustm": "40.7",
            "wgusti": "25.3",
            "wdird": "250",
            "wdire": "WSW",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1012.7",
            "pressurei": "29.91",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Partly Cloudy",
            "icon": "partlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 022356Z 25019G22KT 10SM FEW011 18/10 A2991 RMK AO2 SLP127 T01780100 10194 20167 58005"
        }, {
            "date": {
                "pretty": "5:56 PM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "17",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "12:56 AM GMT on July 03, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "03",
                "hour": "00",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "17.8",
            "tempi": "64.0",
            "dewptm": "10.0",
            "dewpti": "50.0",
            "hum": "60",
            "wspdm": "29.6",
            "wspdi": "18.4",
            "wgustm": "40.7",
            "wgusti": "25.3",
            "wdird": "250",
            "wdire": "WSW",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1012.6",
            "pressurei": "29.91",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Partly Cloudy",
            "icon": "partlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 030056Z 25016G22KT 10SM FEW012 18/10 A2990 RMK AO2 PK WND 25027/0038 SLP126 T01780100"
        }, {
            "date": {
                "pretty": "6:56 PM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "18",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "1:56 AM GMT on July 03, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "03",
                "hour": "01",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "16.7",
            "tempi": "62.1",
            "dewptm": "9.4",
            "dewpti": "48.9",
            "hum": "62",
            "wspdm": "27.8",
            "wspdi": "17.3",
            "wgustm": "40.7",
            "wgusti": "25.3",
            "wdird": "260",
            "wdire": "West",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1012.8",
            "pressurei": "29.91",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Partly Cloudy",
            "icon": "partlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 030156Z 26015G22KT 10SM FEW011 17/09 A2991 RMK AO2 SLP128 T01670094"
        }, {
            "date": {
                "pretty": "7:56 PM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "19",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "2:56 AM GMT on July 03, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "03",
                "hour": "02",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "15.6",
            "tempi": "60.1",
            "dewptm": "9.4",
            "dewpti": "48.9",
            "hum": "67",
            "wspdm": "22.2",
            "wspdi": "13.8",
            "wgustm": "-9999.0",
            "wgusti": "-9999.0",
            "wdird": "270",
            "wdire": "West",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1012.8",
            "pressurei": "29.91",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Partly Cloudy",
            "icon": "partlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 030256Z 27012KT 10SM FEW011 16/09 A2991 RMK AO2 SLP128 T01560094 53000"
        }, {
            "date": {
                "pretty": "8:56 PM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "20",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "3:56 AM GMT on July 03, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "03",
                "hour": "03",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "14.4",
            "tempi": "57.9",
            "dewptm": "9.4",
            "dewpti": "48.9",
            "hum": "72",
            "wspdm": "29.6",
            "wspdi": "18.4",
            "wgustm": "38.9",
            "wgusti": "24.2",
            "wdird": "270",
            "wdire": "West",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1012.9",
            "pressurei": "29.91",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Scattered Clouds",
            "icon": "partlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 030356Z 27016G21KT 10SM FEW011 SCT016 14/09 A2991 RMK AO2 SLP129 T01440094"
        }, {
            "date": {
                "pretty": "9:56 PM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "21",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "4:56 AM GMT on July 03, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "03",
                "hour": "04",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "13.9",
            "tempi": "57.0",
            "dewptm": "9.4",
            "dewpti": "48.9",
            "hum": "74",
            "wspdm": "35.2",
            "wspdi": "21.9",
            "wgustm": "50.0",
            "wgusti": "31.1",
            "wdird": "270",
            "wdire": "West",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1013.2",
            "pressurei": "29.92",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Partly Cloudy",
            "icon": "partlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 030456Z 27019G27KT 10SM FEW011 14/09 A2992 RMK AO2 PK WND 27028/0435 SLP132 T01390094"
        }, {
            "date": {
                "pretty": "10:56 PM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "22",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "5:56 AM GMT on July 03, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "03",
                "hour": "05",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "13.9",
            "tempi": "57.0",
            "dewptm": "9.4",
            "dewpti": "48.9",
            "hum": "74",
            "wspdm": "25.9",
            "wspdi": "16.1",
            "wgustm": "42.6",
            "wgusti": "26.5",
            "wdird": "260",
            "wdire": "West",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1013.5",
            "pressurei": "29.93",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Mostly Cloudy",
            "icon": "mostlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 030556Z 26014G23KT 10SM FEW009 SCT011 BKN014 14/09 A2993 RMK AO2 SLP135 T01390094 10183 20139 53007"
        }, {
            "date": {
                "pretty": "11:56 PM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "23",
                "min": "56",
                "tzname": "America/Los_Angeles"
            },
            "utcdate": {
                "pretty": "6:56 AM GMT on July 03, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "03",
                "hour": "06",
                "min": "56",
                "tzname": "UTC"
            },
            "tempm": "13.3",
            "tempi": "55.9",
            "dewptm": "9.4",
            "dewpti": "48.9",
            "hum": "77",
            "wspdm": "22.2",
            "wspdi": "13.8",
            "wgustm": "-9999.0",
            "wgusti": "-9999.0",
            "wdird": "270",
            "wdire": "West",
            "vism": "16.1",
            "visi": "10.0",
            "pressurem": "1013.6",
            "pressurei": "29.94",
            "windchillm": "-999",
            "windchilli": "-999",
            "heatindexm": "-9999",
            "heatindexi": "-9999",
            "precipm": "-9999.00",
            "precipi": "-9999.00",
            "conds": "Mostly Cloudy",
            "icon": "mostlycloudy",
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "metar": "METAR KSFO 030656Z 27012KT 10SM FEW009 BKN014 BKN018 13/09 A2993 RMK AO2 SLP136 T01330094"
        }],
        "dailysummary": [{
            "date": {
                "pretty": "12:00 PM PDT on July 02, 2012",
                "year": "2012",
                "mon": "07",
                "mday": "02",
                "hour": "12",
                "min": "00",
                "tzname": "America/Los_Angeles"
            },
            "fog": "0",
            "rain": "0",
            "snow": "0",
            "snowfallm": "0.00",
            "snowfalli": "0.00",
            "monthtodatesnowfallm": "0.00",
            "monthtodatesnowfalli": "0.00",
            "since1julsnowfallm": "0.00",
            "since1julsnowfalli": "0.00",
            "snowdepthm": "",
            "snowdepthi": "",
            "hail": "0",
            "thunder": "0",
            "tornado": "0",
            "meantempm": "16",
            "meantempi": "61",
            "meandewptm": "11",
            "meandewpti": "51",
            "meanpressurem": "1013",
            "meanpressurei": "29.91",
            "meanwindspdm": "23",
            "meanwindspdi": "14",
            "meanwdire": "",
            "meanwdird": "260",
            "meanvism": "16",
            "meanvisi": "10",
            "humidity": "",
            "maxtempm": "19",
            "maxtempi": "67",
            "mintempm": "13",
            "mintempi": "55",
            "maxhumidity": "80",
            "minhumidity": "60",
            "maxdewptm": "12",
            "maxdewpti": "53",
            "mindewptm": "9",
            "mindewpti": "49",
            "maxpressurem": "1014",
            "maxpressurei": "29.94",
            "minpressurem": "1011",
            "minpressurei": "29.87",
            "maxwspdm": "40",
            "maxwspdi": "25",
            "minwspdm": "8",
            "minwspdi": "5",
            "maxvism": "16",
            "maxvisi": "10",
            "minvism": "16",
            "minvisi": "10",
            "gdegreedays": "12",
            "heatingdegreedays": "4",
            "coolingdegreedays": "0",
            "precipm": "0.00",
            "precipi": "0.00",
            "precipsource": "",
            "heatingdegreedaysnormal": "2",
            "monthtodateheatingdegreedays": "6",
            "monthtodateheatingdegreedaysnormal": "4",
            "since1sepheatingdegreedays": "",
            "since1sepheatingdegreedaysnormal": "",
            "since1julheatingdegreedays": "6",
            "since1julheatingdegreedaysnormal": "4",
            "coolingdegreedaysnormal": "1",
            "monthtodatecoolingdegreedays": "0",
            "monthtodatecoolingdegreedaysnormal": "2",
            "since1sepcoolingdegreedays": "",
            "since1sepcoolingdegreedaysnormal": "",
            "since1jancoolingdegreedays": "23",
            "since1jancoolingdegreedaysnormal": "42"
        }]
    }
}

date_range_response = {
    "response": {
        "version": "0.1",
        "termsofService": "http://www.wunderground.com/weather/api/d/terms.html",
        "features": {
            "planner": 1
        }
    },
    "trip": {
        "title": "Historical Summary for July 01 - July 31",
        "airport_code": "KSFO",
        "error": "",
        "period_of_record": {
            "date_start": {
                "date": {
                    "epoch": "867783600",
                    "pretty": "12:00 PM PDT on July 01, 1997",
                    "day": 1,
                    "month": 7,
                    "year": 1997,
                    "yday": 181,
                    "hour": 12,
                    "min": "00",
                    "sec": 0,
                    "isdst": "1",
                    "monthname": "July",
                    "weekday_short": "Tue",
                    "weekday": "Tuesday",
                    "ampm": "PM",
                    "tz_short": "PDT",
                    "tz_long": "America/Los_Angeles"
                }
            },
            "date_end": {
                "date": {
                    "epoch": "1341255600",
                    "pretty": "12:00 PM PDT on July 02, 2012",
                    "day": 2,
                    "month": 7,
                    "year": 2012,
                    "yday": 183,
                    "hour": 12,
                    "min": "00",
                    "sec": 0,
                    "isdst": "1",
                    "monthname": "July",
                    "weekday_short": "Mon",
                    "weekday": "Monday",
                    "ampm": "PM",
                    "tz_short": "PDT",
                    "tz_long": "America/Los_Angeles"
                }
            }
        },
        "temp_high": {
            "min": {
                "F": "60",
                "C": "16"
            },
            "avg": {
                "F": "71",
                "C": "22"
            },
            "max": {
                "F": "97",
                "C": "36"
            }
        },
        "temp_low": {
            "min": {
                "F": "48",
                "C": "9"
            },
            "avg": {
                "F": "55",
                "C": "13"
            },
            "max": {
                "F": "63",
                "C": "17"
            }
        },
        "precip": {
            "min": {
                "in": "0.00",
                "cm": "0.0"
            },
            "avg": {
                "in": "0.00",
                "cm": "0.0"
            },
            "max": {
                "in": "0.01",
                "cm": "0.2"
            }
        },
        "dewpoint_high": {
            "min": {
                "F": "48",
                "C": "9"
            },
            "avg": {
                "F": "56",
                "C": "13"
            },
            "max": {
                "F": "64",
                "C": "18"
            }
        },
        "dewpoint_low": {
            "min": {
                "F": "45",
                "C": "7"
            },
            "avg": {
                "F": "51",
                "C": "11"
            },
            "max": {
                "F": "59",
                "C": "15"
            }
        },
        "cloud_cover": {
            "cond": "mostly sunny"
        },
        "chance_of": {
            "tempoversixty": {
                "name": "Warm",
                "description": "temperature over 60°F / 16°C and below 90°F / 32°C",
                "percentage": "100"
            },
            "chanceofwindyday": {
                "name": "Windy",
                "description": "average wind over 10 mph / 15km/h",
                "percentage": "69"
            },
            "chanceofpartlycloudyday": {
                "name": "Partly Cloudy",
                "description": "",
                "percentage": "48"
            },
            "chanceofsunnycloudyday": {
                "name": "Sunny",
                "description": "",
                "percentage": "37"
            },
            "chanceofcloudyday": {
                "name": "Cloudy",
                "description": "",
                "percentage": "15"
            },
            "chanceoffogday": {
                "name": "Fog",
                "description": "",
                "percentage": "11"
            },
            "chanceofhumidday": {
                "name": "Humid",
                "description": "dew point over 60°F / 16°C",
                "percentage": "6"
            },
            "chanceofprecip": {
                "name": "Precipitation",
                "description": "",
                "percentage": "1"
            },
            "chanceofrainday": {
                "name": "Rain",
                "description": "",
                "percentage": "1"
            },
            "tempoverninety": {
                "name": "Hot",
                "description": "temperature over 90°F / 32°C",
                "percentage": "0"
            },
            "chanceofthunderday": {
                "name": "Thunderstorms",
                "description": "",
                "percentage": "0"
            },
            "chanceofsnowonground": {
                "name": "Ground Snow",
                "description": "",
                "percentage": "0"
            },
            "chanceoftornadoday": {
                "name": "Tornado",
                "description": "",
                "percentage": "0"
            },
            "chanceofsultryday": {
                "name": "Sweltering",
                "description": "dew point over 70°F / 21°C",
                "percentage": "0"
            },
            "tempbelowfreezing": {
                "name": "Freezing",
                "description": "temperature below 32°F / 0°C",
                "percentage": "0"
            },
            "tempoverfreezing": {
                "name": "Cool",
                "description": "temperature between 32°F / 0°C and 60°F / 16° C",
                "percentage": "0"
            },
            "chanceofhailday": {
                "name": "Hail",
                "description": "",
                "percentage": "0"
            },
            "chanceofsnowday": {
                "name": "Snow",
                "description": "",
                "percentage": "0"
            }
        }
    }
}
